#
# spec file for package mpv
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
# Copyright (c) 2012 Jiri Slaby <jslaby@suse.de>
# Copyright (c) 2011-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150400
%bcond_without jxl
%else
%bcond_with jxl
%endif
%define lname   libmpv2
Name:           mpv
Version:        0.36.0+git20230826.83c0e980
Release:        1.1
Summary:        Advanced general-purpose multimedia player
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Players
URL:            http://mpv.io
Source:         %{name}-%{version}.tar.xz
Source2:        %{name}.changes
# PATCH-FIX-OPENSUSE do not require equal libav versions, obs rebuilds as needed
Patch0:         mpv-make-ffmpeg-version-check-non-fatal.patch
Patch1:         0001-Revert-meson-bump-required-version-to-0.62.patch
# Install docs in proper directory
Patch2:         fix-docs-path.patch
BuildRequires:  bash
BuildRequires:  hicolor-icon-theme
BuildRequires:  linux-kernel-headers
BuildRequires:  meson >= 0.60.3
# Needed any lua to convert the bash-completion
BuildRequires:  lua
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  python3-docutils
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa) >= 1.0.18
BuildRequires:  pkgconfig(caca) >= 0.99.beta18
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(dvdnav) >= 4.2.0
BuildRequires:  pkgconfig(dvdread) >= 4.1.0
BuildRequires:  pkgconfig(egl) >= 1.4
BuildRequires:  pkgconfig(ffnvcodec) >= 8.2.15.7
BuildRequires:  pkgconfig(gbm) >= 17.1.0
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(lcms2) >= 2.6
BuildRequires:  pkgconfig(libarchive) >= 3.4.0
BuildRequires:  pkgconfig(libass) >= 0.12.2
BuildRequires:  pkgconfig(libavcodec) >= 58.12.100
BuildRequires:  pkgconfig(libavdevice) >= 57.0.0
BuildRequires:  pkgconfig(libavfilter) >= 7.14.100
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(libavformat) >= 59.27.100
BuildRequires:  pkgconfig(libavif) >= 0.11.1
BuildRequires:  pkgconfig(libavutil) >= 57.24.100
%else
BuildRequires:  pkgconfig(libavformat) >= 58.9.100
BuildRequires:  pkgconfig(libavutil) >= 56.12.100
%endif
BuildRequires:  pkgconfig(libbluray) >= 0.3.0
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcdio_paranoia)
BuildRequires:  pkgconfig(libdrm) >= 2.4.75
BuildRequires:  pkgconfig(libiso9660)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpulse) >= 1.0
BuildRequires:  pkgconfig(libswresample) >= 3.0.100
BuildRequires:  pkgconfig(libswscale) >= 5.0.101
BuildRequires:  pkgconfig(libva) >= 1.1.0
BuildRequires:  pkgconfig(lua5.1)
BuildRequires:  pkgconfig(openal) >= 1.13
BuildRequires:  pkgconfig(python3)
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} > 150400
BuildRequires:  pkgconfig(libsixel) >= 1.5
%endif
BuildRequires:  pkgconfig(rubberband) >= 3.0.0
BuildRequires:  pkgconfig(uchardet)
BuildRequires:  pkgconfig(vapoursynth) >= 24
BuildRequires:  pkgconfig(vapoursynth-script) >= 23
BuildRequires:  pkgconfig(vdpau) >= 0.2
BuildRequires:  pkgconfig(x11) >= 1.0.0
BuildRequires:  pkgconfig(xext) >= 1.0.0
BuildRequires:  pkgconfig(xkbcommon) >= 0.3.0
BuildRequires:  pkgconfig(xpresent) >= 1.0.0
BuildRequires:  pkgconfig(xrandr) >= 1.4.0
BuildRequires:  pkgconfig(xscrnsaver) >= 1.0.0
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(zimg) >= 2.9
BuildRequires:  pkgconfig(zlib)
%if %{with jxl}
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libjxl_threads)
%endif
Requires:       hicolor-icon-theme
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun):hicolor-icon-theme
Requires(postun):update-desktop-files
# Used via LUA scripts
Recommends:     yt-dlp
Conflicts:      mpv-plugin-mpris < 0.4
# Obsoletion of mplayer2 that is dead for 2 years now
Provides:       mplayer2 = 20140101
Obsoletes:      mplayer2 < 20140101
# Use libplacebo v5.264 for Leap 15.5
%if 0%{?sle_version} >= 150400 && 0%{?is_opensuse}
BuildRequires:  (pkgconfig(libplacebo) >= 5 with pkgconfig(libplacebo) < 6.292.0)
%endif
# Use libplacebo v6.292 for Tumbleweed
%if 0%{?suse_version} >= 1550
BuildRequires:  pkgconfig(libplacebo) >= 6.292.0
BuildRequires:  pkgconfig(shaderc)
%endif
# mujs is not available for Leap 15.5
%if 0%{?suse_version} >= 1550
BuildRequires:  pkgconfig(mujs)
%endif
BuildRequires:  pkgconfig(libva-wayland) >= 1.1.0
BuildRequires:  pkgconfig(vulkan) >= 1.0.61
BuildRequires:  pkgconfig(wayland-client) >= 1.20.0
BuildRequires:  pkgconfig(wayland-cursor) >= 1.20.0
BuildRequires:  pkgconfig(wayland-egl) >= 9.0.0
BuildRequires:  pkgconfig(wayland-protocols) >= 1.25
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150300
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.3.48
%endif
# JIT for lua.
%ifarch aarch64 %{ix86} x86_64
BuildRequires:  pkgconfig(luajit)
%else
BuildRequires:  pkgconfig(lua5.1)
%endif

%description
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name} = %{version}
Requires:       bash-completion
Recommends:     xrandr
Supplements:    (mpv and bash)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name} = %{version}
Supplements:    (mpv and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%package devel
Summary:        A library to link together with mpv player
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains all the development files.

%package -n %{lname}
Summary:        A library to link together with mpv player
Group:          System/Libraries

%description -n %{lname}
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains a library that can other apps use to utilize the mpv
features.

%prep
%autosetup -p1

# I hate UNKNOWN so lets put decent info there.
MODIFIED="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE2}")"
DATE="$(date -d "$MODIFIED" "+%%b %%e %%Y")"
sed -i "s|UNKNOWN|$DATE|g;s|VERSION|\"%{version}\"|g" common/version.c

%build
# We don't want to rebuild all the time.
myopts=" -Dbuild-date=false"
# Disable pipwire for Leap because of build error
%if 0%{?suse_version} <= 1500 && 0%{?sle_version} < 150500
myopts+=" -Dpipewire=disabled"
%endif
# Needs libavutil >= 58.11.100 (unreleased as of 2023-07-14)
myopts+=" -Dvulkan-interop=disabled"
%meson \
  --auto-features=auto       \
  -Dcdda=enabled             \
  -Dlibmpv=true              \
  -Ddvbin=enabled            \
  -Ddvdnav=enabled           \
  -Dopenal=enabled           \
  ${myopts}                  \
  %{?nil}
%meson_build

%install
%meson_install

install -D -m 0644 etc/input.conf %{buildroot}%{_sysconfdir}/%{name}/input.conf
install -D -m 0644 etc/mpv.conf %{buildroot}%{_sysconfdir}/%{name}/mpv.conf
# remove shebang
sed -i -e '1d' %{buildroot}%{_datadir}/bash-completion/completions/mpv

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
%license LICENSE.GPL
%doc Copyright README.md RELEASE_NOTES
%doc %{_defaultdocdir}/%{name}/input.conf
%doc %{_defaultdocdir}/%{name}/mplayer-input.conf
%doc %{_defaultdocdir}/%{name}/mpv.conf
%doc %{_defaultdocdir}/%{name}/restore-old-bindings.conf
%dir %{_sysconfdir}/%{name}/
%ghost %dir %{_sysconfdir}/%{name}/scripts/
%config %{_sysconfdir}/%{name}/encoding-profiles.conf
%config %{_sysconfdir}/%{name}/input.conf
%config %{_sysconfdir}/%{name}/mpv.conf
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor
%{_datadir}/metainfo/mpv.metainfo.xml
%{_mandir}/man?/%{name}.?%{?ext_man}

%files zsh-completion
%{_datadir}/zsh/site-functions/_mpv

%files bash-completion
%{_datadir}/bash-completion/completions/mpv

%files -n %{lname}
%{_libdir}/*.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Aug 27 2023 llyyr <llyyr.public@gmail.com>
- Disable mujs backend for Leap because it's not available there
* Sat Aug 26 2023 Enrico Belleri <kilgore.trout@idesmi.eu>
- Add fix-docs-path.patch to install docs in our default docdir
- Enable jxl
- Use meson auto-features instead of disabling everything manually
- Small corrections to specfile
- Update to version v0.36.0+git20230826.83c0e980:
  * hwtransfer: check if the source format is accepted directly by the VO
  * hwtransfer: use the right hardware config to find conversion targets
  * autoconvert: destroy sub filter immediately if reconfiguration is needed
  * output_chain: don't reset autoconvert on changes to unrelated filters
  * hwtransfer: implement support for hw->hw format conversion
  * player: make all autoload extensions configurable
  * player: use audio pts corresponding to playing audio on EOF
  * input: add missing keypad key defines
  * sub/osd: signal osd_changed on resize
  * win32: don't ignore --screen and --fs-screen
  * DOCS/mpv: document ZOOMIN & ZOOMOUT multimedia keys
  * input: add new keys: Back, Tools, ZoomIn, ZoomOut
  * vo_gpu_next: move line to correct location (cosmetic)
  * vo_gpu_next: correctly handle GAMUT_AUTO
  * ci/mingw: disable vulkan for 32-bit build
  * ci/mingw: don't include useless DLLs in artifact
  * ci/mingw: refactor build script into functions
  * ci/mingw: enable more ffmpeg features
  * ci/mingw: add necessary deps and enable vulkan
  * ci/mingw: move functional test to workflow
  * ci/mingw: update dependency versions
  * vo_gpu_next: reword error message on empty screenshot
  * DOCS/options: clarify the video-pan-x/y example
  * aspect: change --video-pan-x/y to be relative to the destination rect
  * aspect: don't allow scaled_src_size be 0
  * DOCS/options: fix typo in video-pan-x example
  * meson: rename all features with underscores
  * context_drm_egl: remove references to VAAPI in error messages
  * context_drm_egl: more correctness fixes for uninit procedure
  * Revert "ao/pulse: implement period_size"
  * w32_common: try to get the monitor from the window bounds
  * w32_common: don't fit to screen when VO_WIN_FORCE_POS is set
  * ao/pulse: implement period_size
  * ao/jack: set device_buffer to JACK buffer size
  * demux_mf: utilize stdbool bool for if a format specifier was bad
  * demux_mf: early exit with the '%%%%' case
  * win32_common: fixes minimized window being focused on launch
  * ao_oss: add "spdif" passthrough support for high bitrate codecs (e.g. Dolby Atmos, DTS-HD, etc.) over HDMI
  * drm_common: skip cards that don't have connected outputs
  * meson: remove redundant libplacebo version check for Vulkan interop
  * x11: set sizehint for fs-screen and fs-screen-name
  * x11: remove xinerama and refactor window geometry
  * x11: require randr 1.4
  * context_drm_egl: don't free egl properties if they are null
  * vo_gpu_next: correctly clear removed hooks
  * sd_lavc: use SUB_GAP_THRESHOLD for overlaps/gaps
  * Revert "sub/sd_lavc: don't check endpts when getting subs"
  * vo_gpu_next: fix typo in video_screenshot()
  * vo_gpu_next: add --libplacebo-opts
  * vo_gpu_next: don't re-set frame_mixer
  * vo_gpu_next: move allow_delayed to move appropriate place
  * vo_gpu_next: switch to new pl_options system
  * TOOLS/lua/autoload: Enable run-time updates of options
  * TOOLS/lua/autoload: may specify loading only one type of files
  * vo_gpu_next: fix leak of --icc-profile-auto on uninit
  * vo_gpu_next: drop redundant PL_HAVE_LCMS check
  * ci: update freebsd to latest release channel
  * ci: disable libplacebo in msys2 build
  * vo_gpu_next: use pl_dispatch_info_move to avoid useless data copy
  * libplacebo: drop PL_API_VER compatibility paths
  * ra_pl: drop PL_API_VER compatibility paths
  * vo_gpu_next: drop PL_API_VER compatibility paths
  * meson: remove redundant libplacebo-next check
  * hwdec_cuda: drop old PL_API_VER compatibility path
  * meson: bump minimum libplacebo dependency to v6.292
  * stats.lua: display output resolution if it differs to native one
  * stats.lua: hide window scale in fullscreen
  * vo_gpu: allow --hdr-peak-decay-rate=0.0
  * loadfile: avoid infinite playlist loading loops
  * build: check for SNDCTL_DSP_HALT for oss-audio
  * vo: clear vsync_offset if drawing while paused
  * win32: fix display resolution calculation on mulitple monitors
  * demux_playlist: remove len restriction on headerless m3u
  * wayland: clear all keys on keyboard_handle_leave
  * wayland: clear saved mpkey more aggressively
  * wayland: use fallback for display-fps/width/height
  * x11: add --x11-wid-title option
  * player: add playlist-path properties
  * vf_vapoursynth: save display resolution as a variable
  * player: add --term-remaining-playtime option
  * player: make sub-pos a float value
  * x11_common: drop unnecessary NULL check
  * x11_common: avoid unnecessary XUnmapWindow() call
  * stats.lua: use video-params/aspect-name
  * player/command: add video-params/aspect-name
  * ytdl_hook: improve Windows exe search with suffix
  * command: don't print "unknown" on video tracks
  * player/video: avoid spamming logs with EOF
  * audio: drain ao before setting pause
  * command: show "no" for hwdec-current if hwdec failed
  * command: fix some fringe play-dir behavior
  * sub/sd_lavc: don't check endpts when getting subs
  * sub: fix switching tracks while paused
  * path-unix: abort on path truncation
  * osc: support speed-independent time-remaiing display
  * command: fix stack smashing when displaying aspect-ratio
  * external_files: add sbv to the sub whitelist
  * external_files: alphabetize file extensions
  * DOCS: update LGPL building instructions
  * m_option: change m_option_type_aspect to double
  * vo_gpu_next: actually fix screenshots with PAR
  * ao_audiotrack: enable pcm-float by default
  * ao_audiotrack: support more channel layouts
  * ao_audiotrack: support media role
  * ao_audiotrack: don't ignore ao_read_data return value
  * ao_audiotrack: allow byte buffer data transfer for float samples
  * ao_audiotrack: align buffer size to sample size
  * ao_audiotrack: do not needlessly resample
  * ao_audiotrack: fix broken exception checks
  * ao_audiotrack: remove unused writeV23
  * vo_gpu_next: take into account PAR when taking screenshots
  * ad_spdif: fix this not working at all
  * vo_gpu_next: add ability to use named hook params
  * mp_image: properly infer color levels for some pixfmts
  * vo_gpu_next: increase non-interpolation queue size
  * vo_gpu_next: update for new pl_filter configuration API
  * win32: signal VO_EVENT_DPI on dpi changes
  * test/meson: add missing avutil dependency to chmap test
  * test: indicate test function ran in log
  * test: enable log messages for libmpv test
  * test: refactor helper methods to be universally usable
  * options: fix relative time parsing
  * options: rename variables in parse_timestring
  * vd_lavc: repeatedly attempt to fallback if hwdec fails in reinit
  * DOCS/options: fix typo in hdr-peak-percentile
  * vo_gpu/vo_gpu_next: fix setting an empty dscale
  * builtin.conf: add --hdr-peak-percentile=99.995 to gpu-hq
  * vo_gpu_next: add --hdr-peak-percentile
  * player/main: do not print build time, if it is unknown
  * version: move NO_BUILD_TIMESTAMPS check to version.h.in
  * build: remove version.py
  * vo_vdpau: set hwdec image format
  * test: bump libmpv test timeout
  * drm: bump minimum version to 2.4.105
  * ci: update the mpv.com path
  * build: remove outdated generated directory
  * ao_pipewire: set media role during init()
  * audio: add AO_INIT_MEDIA_ROLE_MUSIC
* Mon Jul 31 2023 llyyr.public@gmail.com
- Remove waf build: removed upstream
- Make meson a hard requirement now
- Bump libplacebo requirement to 6.292.0 for Tumbleweed
- Add patch 0001-Revert-meson-bump-required-version-to-0.62.patch
  to lower meson requirement for Leap
- Update to version 0.36.0+git.20230730.1bbc7a2c:
  * ao_sndio: use sio_flush() to improve controls responsiveness
  * draw_bmp: fix overflowing coordinates in mark_rcs
  * Revert "audio: add AOCONTROL_UPDATE_MEDIA_ROLE"
  * Revert "ao_pipewire: handle AOCONTROL_UPDATE_MEDIA_ROLE"
  * meson: look for linux/input-event-codes.h with libwayland flags
  * version.py: fix build date
  * options: restore old default sub selection behavior
  * vo_gpu_next: fix assertion on wayland
  * vo_gpu_next: delay swapchain submit until flip_frame()
  * path-win: move state directory to %%LOCALAPPDATA%%
  * path-win: add subdirectory for cache
  * Revert "ci/msys2: double down on running meson through python3.11"
  * ad_spdif: fix segfault due to early deallocation
  * test: enhance libmpv test
  * player/video: check for track and decoder existence
  * video_writer: fix gamma for YUV screenshots
  * image_writer: log pixfmt conversion
  * encode_lavc: fix leak of codecpar
  * zimg: fix abort on subsampled input with odd heights
  * demux_mkv: add missing space to log msg
  * build: remove unneeded libdl requirement for vaapi
  * build: refactor vaapi handling
  * ci/mingw: reduce git clone depth to 1
  * ci/mingw: use ccache
  * ci/mingw: disable fail-fast
  * ci/mingw: check if binary is runnable before packaging
  * language-posix: as a fallback, treat "C" as "en"
  * msg: print MSGL_WARN and higher error messages to stderr
  * build: vaapi-x-egl is not used anywhere, remove it
  * build: vaapi-egl should explicitly depend on egl
  * build: vaapi-drm and vaapi-wayland do not depend on egl
  * ci/mingw: update luajit to fix i686 crashes
  * wayland: restore xkb_keysym_to_utf8 handling
  * build: internally rename gl-wayland to egl-wayland
  * waf: remove waf as a build system
* Sun Jul 23 2023 llyyr.public@gmail.com
- Update to version 0.36.0+git.20230723.60a26324:
  * Update VERSION
  * Release 0.36.0
  * Revert "vo_gpu_next: use pl_dispatch_info_move to avoid useless data copy"
  * ao_pipewire: for_each_sink: properly check termination condition
  * DOCS/vo: clarify dmabuf-wayland a bit
  * vo_dmabuf_wayland: correctly handle force-window
  * player/video: check for forced eof
  * vd_lavc: respect vd-lavc-software-fallback opt
  * vo_vaapi: restore hardware video decoding
  * vo_vaapi: fix segfault in draw_osd
  * ao_pipewire: use native buffersize by default
  * terminal-unix: fix not listening on input after being foregrounded
  * osc: don't add margins to osc-deadzonesize
  * DOCS: clarify screenshot window and screenshot-sw
  * vo_drm: remove VOCTRL_SCREENSHOT_WIN
  * screenshot: implement screenshot-window in sw for most VOs
  * screenshot: clarify software screenshot logic
  * image_writer: use proper specifier for int64_t
  * {zsh,bash}-completion: run mpv with --no-config
  * bash-completion: do not complete removed options
  * zsh-completion: do not complete removed options
  * zimg: fix broken sig_peak handling
  * image_writer: move tag_csp check into image_writer_flexible_csp()
  * image_writer: replace sprintf usage
  * image_writer: share some code between write_lavc and write_avif
  * image_writer: error check avif-pixfmt option
  * image_writer: fix still-picture option for AVIF
  * image_writer: remove duplicate packet writing code
  * TOOLS: remove obsolete travisCI-related scripts
  * wayland_common: remove questionable gcd impl and global state
  * wayland: don't treat tiled and maximized windows the same
  * wayland: add locked_size convenience shorthand
  * builtin.conf: add --hdr-contrast-recovery to gpu-hq
  * vo_gpu_next: add --hdr-contrast-recovery/smoothness
  * builtin.conf: unset default languages in libmpv and encode profiles
  * vd_lavc: repeatedly attempt to fallback if hwdec fails in receive_frame
  * wayland: handle modifier keys correctly
  * vo_gpu_next: add --target-contrast option
  * loadfile: make get_audio_lang function static
  * DOCS/release-policy.md: add additional advice
  * loadfile: compute audio lang for sub selection when using lavfi-complex
  * wayland: wrap resize requests in prepare_resize
  * sd_ass: fix converted subtitles having too-wide borders
  * sd_ass: don't reconfigure ass on every frame
  * player: set default cache dir on macOS
  * DOCS/mpv: clarify the location of cache/state files
  * path-win: implement cache directories
  * DOCS/interface-changes: document change in ctrl+h behaviour
  * vd_lavc: map `hwdec=yes` to `hwdec=auto-safe`
  * vd_lavc: add `drm` and `drm-copy` to the `auto-safe` list
  * input: update ctrl+h to toggle `auto-safe` rather than `auto`
  * vd_lavc: try other hwdecs when falling back after an hwdec failure
* Fri Jul 14 2023 mia@0x0.st
- Update to version 0.35.1+git.20230714.1f683401:
  * vo_dmabuf_wayland: error out if compositor doesn't support the format
  * build: make dmabuf-wayland a build option and require drm
  * console: sort the output from the `help` command
  * player: delete watch later redirect entries again
  * wayland: use xdg_surface_set_window_geometry
  * Revert "wayland_gl: wait until resize to create egl_window"
  * vo_dmabuf_wayland: guard in destroy_osd_buffers
  * vo_dmabuf_wayland: stop lazy loading hwdec
  * vo_dmabuf_wayland: don't try to get pts without frame->current
  * draw_bmp: ensure last slice is less than total width (again)
  * vo_dmabuf_wayland: add osd support
  * vo_dmabuf_wayland: init wl_list at the top of preinit
  * vo_dmabuf_wayland: stop guarding viewport interfaces
  * video/image_writer: check for write errors
  * video/image_writer: fix file leak in error path
  * wscript: add 1.32 protocols to sources
  * stats.lua: set sans-serif as default font
  * wayland: add xdg_toplevel.wm_capabilities handler
  * wayland: add support for suspended toplevel state
  * wayland: add cursor-shape-v1 support
  * vd_lavc: fix delay_queue for videos with frames < max_delay_queue
  * vd_lavc: prefer d3d11va-copy over dxva2-copy
  * vo_wlshm: bail out of resize if width/height is 0
  * wayland: fix memory leak with multiple monitors
  * player: delete watch_later file after successful load
  * json: unify json_parse depth to MAX_JSON_DEPTH=50
  * terminal-unix: better error detection logic
  * TOOLS/idet: fix some outdated cli syntax
  * demux_playlist: sort files before directories
  * demux_playlist: add option to control recursive directory loading
  * TOOLS/lua/autoload: allow extending ext sets from script-opts
  * various: correctly ignore cache files with --no-config
  * vo_gpu/vo_gpu_next: enable gpu shader and icc cache by default
  * vo_gpu: fix some cache related memory leaks
  * player: add --input-cursor-passthrough option
  * TOOLS/lua/autoload: avoid unnecessary playlist manipulation, performance
  * wscript: bump required libplacebo-next version to 5.266
  * vo_gpu_next: remove synchronization from info_callback
  * vo_gpu_next: use pl_dispatch_info_move to avoid useless data copy
  * ci/msys2: double down on running meson through python3.11
  * vo_x11: don't rely on XFree to free calloc-ed data
  * vo_x11: check for calloc() failure
  * win32: add support for drag-and-drop option
  * options: add no to drag-and-drop
  * test/meson: explicitly specify lavf dependency
  * player/screenshot: add "screenshot" logger
  * video/image_writer: add avif screenshot support
  * options: drop unnecessary casts
  * options: use designated initializer
  * vd_lavc: do inline string array initialisation for hwdec_api
  * vd_lavc: let the user provide a priority list of hwdecs to consider
  * osdep: remove erroneous POLLERR emulation
  * wayland: remove erroneous POLLERR usage
  * image_writer: respect jpeg-quality when using ffmpeg for writing
  * image_writer: remove unused struct fields
  * mp_image: abort on av_buffer_ref() failure
  * loadfile: fix leak due to setting NULL parent
  * hwdec: fix undeclared identifier in mediacodec_embed
  * vo_drm: fix null dereference and using closed fd
  * github/workflows: do not copyback files from freebsd VM
  * github/workflows: bump freebsd VM memory size to 8GB
  * hwdec: do not add hwdec device if it failed to create
  * vd_lavc: check if av_device_ref is available
  * ci/msys2: switch to Python 3.11 to fix crashes during build
  * loadfile: insert missing parentheses
  * osc: add toggle for forced-only subs
  * loadfile: expose auto-forced-only when printing stream info
  * command: add sub-forced-only-cur prop
  * command: report auto-forced-only flag in track desc
  * sub: rewrite auto-forced-only support
  * player: add more precise sub fallback options
  * options: default slang to auto
  * loadfile: support "auto" as a language option
  * loadfile: use mp_match_lang_single
  * loadfile: take a const char* in match_lang
  * loadfile: short-circuit early on null stream language
  * osdep: add mp_get_user_langs
  * osdep: move cfstr<->cstr conversions to a new apple_utils.c file
  * misc: add language-matching utilities
  * options: set subs-with-matching-audio to off by default
  * vo: hwdec: prioritise `drmprime` over `drmprime_overlay`
  * ad_lavc: check for allocation failure
  * vo_gpu_next: add --corner-rounding option
  * vo_gpu_next: add missing --gamut-mapping-mode options
  * ao_pipewire: bump dependency to 0.3.48
  * ao_wasapi: use client name instead of hardcoded string
  * ao_wasapi: remove infinite loop hack in AOCONTROL_UPDATE_STREAM_TITLE
  * demux/demux_lavf: avoid leaking AVFormatContext during demux_open_lavf
  * vo_dmabuf_wayland: drop linux-dmabuf-v2 (again)
  * wayland: bump wayland-protocols to 1.25
  * wayland: bump required version to 1.20
  * DOCS: fix admonition typo
  * vo_dmabuf_wayland: update the image of pending buffers
  * vo_dmabuf_wayland: use a minimum of 15 buffers
  * ci: use a different mirror for freetype
  * player: add drag-and-drop option
  * wayland: avoid misleading log messages on drag/drop
  * ci/mingw: add dlltool to the meson crossfile
  * mpv.desktop: add Russian translation for GenericName
  * ci/mingw: remove cache
  * ci/mingw: update dependencies versions
  * ci/msys2: enable egl-angle-lib
  * github/workflows/build.yml: install ca-certificates package on msys2
  * bootstrap.py: update waf to 2.0.25
  * DOCS/mpv: add an example for applying profiles to certain paths
  * player: don't load unwanted files after 519e56f
  * hwdec_cuda: bump required headers version for timeline semaphores
  * hwdec_cuda: clear vulkan semaphore fd after passing ownership to cuda
  * hwdec_vulkan: respect probing flag when logging during init
  * vulkan: don't assume all ra_ctx implementations have a swapchain
  * hwdec_cuda: remove usage of deprecated libplacebo sync API
  * video/out/android: assert WinID value before use
  * path: handle URLs consistently in mp_basename
  * lua: read_options: find script-opts prefix at index 1 exactly
  * demux/demux_lavf: strip URL parameters before matching extension
  * hwdec_vulkan: enable AV1 support if available
  * hwdec_vulkan: check for the correct libplacebo version
  * vo: hwdec_aimagereader: fix compile
  * hwdec_vulkan: simplify requirement checks for Vulkan interop
  * vo/vulkan: do not define zero sized array
  * hwdec_vulkan: account for vulkan frames now using presentation size
  * f_hwtransfer: disable vulkan multiplane images when uploading from cuda
  * hwdec_vulkan: use bwdif_vulkan as deinterlacing auto filter
  * vo: vulkan: request additional extensions and features for ffmpeg
  * hwdec_vulkan: add Vulkan HW Interop
  * vo: hwdec: Pass the ra_ctx to hwdecs instead of just the ra
  * vo_gpu_next: fix to allow using dllimport
  * vo_gpu_next: respect `gl->flipped`
  * opengl: move `ra_gl_ctx_params.flipped` to `struct GL`
  * vo: make mp_frame_perf thread safe
  * vo_gpu_next: add size guard for pass->num_samples
  * vo_gpu_next: synchronize voctrl_performance_data access
  * vo_gpu_next: fix off by one in info_callback
  * vo_dmabuf_wayland: rewrite around wl_list
  * vo_gpu_next: fix build on older libplacebo
  * vo_gpu_next: update to new libplacebo gamut mapping API
  * vo_gpu_next: remove --tone-mapping-crosstalk
  * context_drm_egl: check for non-existant drm in uninit
  * player: improve diagnostics around writing watch_later files
  * path: let configdir also override "cache" and "state" paths
  * path: simplify "cache" and "state" fallback
  * player: always try to detect subtitle language from file name
  * ra_d3d11: change how messages are ignored during texture size lookup
  * wayland: improve guessing when mpv is focused
  * demux/demux_lavf: pass-through mime_type
  * demux/demux_lavf: pass-through filename for HLS
  * Revert "demux/demux_lavf: pass dummy filename when an HLS mimetype is detected"
  * demux/demux_lavf: pass dummy filename when an HLS mimetype is detected
  * vo_gpu_next: allow to use ICC profile luminance value
  * mp_image: use the ffmpeg interlaced frame flags where available
  * ao_oss: return actual OSS playing state
  * player: use XDG_CACHE_HOME by default
  * player: use XDG_STATE_HOME for watch_later
  * path: expand internal path selection API to allow for additional types
  * osdep: separate out macos paths from path-unix.c
  * DOCS/options: document required parameter for --x11-name
  * meson: bump required version to 0.62
  * wayland: add support for wl_surface.preferred_buffer_scale
  * options: read config file as stream
  * ci: switch to lua51 for MSYS build
  * ci: use auto detection for lua library version for MSYS
  * charset_conv: fix memory corruption in mp_iconv_to_utf8
  * sub: fix UPDATE_SUB_HARD for converted and external subtitles
  * console.lua: add a script-opt for the border size
  * vo_gpu_next: fixes to allow using dllimport
  * ao_pipewire: clarify --pipewire-buffer=native
  * ao_pulse: clarify --pulse-buffer=native
  * ao_pipewire: let sound server determine latency
  * ao_pipewire: give sound server more flexibility for buffers
  * hwdec_drmprime: support rpi4_8 and rpi4_10 formats
  * ytdl_hook: fix clip start and end
  * libmpv: fix file name in documentation
  * meson: use the new build_options method
  * wayland: correctly scale configure_bounds
  * player/screenshot: avoid non-sRGB spaces with --screenshot-tag-csp=no
  * video/out/gpu: Fix compilation warning of out of bound access
  * mp_image: always add AV_FRAME_DATA_DOVI_METADATA when present
  * ci: add a workflow that lints commit messages
  * auto_profiles: try to distinguish invalid properties better
  * auto_profiles.lua: apply profiles when conditions are truthy
  * osc: skip rendering when osd_dimensions are 0
  * win32: follow Windows settings and update dark mode state
  * d3d11: retry device creation without debug, if SDK is not available
  * build: add check for eglext_angle.h when checking for ANGLE
  * context_angle: include eglext_angle.h explicitly
  * DOCS/input: fix typo
  * auto_profiles: check for non-existent properties
  * various: fix various typos in the code base
  * various: fix typos
  * demux_lavf: update to handle deprecation of `io_close`
  * ci: bump cache version to rebuild libplacebo
  * ci/mingw: require libplacebo-next
  * build: add an option to control gpu-next
  * ci/mingw: update meson
  * meson: fix libplacebo-next version comparison
  * vo_gpu_next: drop various PL_API_VER checks
  * wscript: bump libplacebo-next required version to 5.264
  * meson: bump libplacebo-next required version to 5.264
  * player/screenshot: add filename return field
  * player: set playlist title to media title if not set already
  * Revert "player: set playlist title to media title if not set already"
  * meson: rst2pdf handle dependency file
  * TOOLS/docutils-wrapper: handle commands without depfile
  * TOOLS/docutils-wrapper: properly propagate failures
  * TOOLS/docutils-wrapper: gracefully remove non-existing files
  * DOCS/lua: fix typo
  * options: enable scripts related opts also with cplugins.
* Sat Mar 18 2023 mia@0x0.st
- Update to version 0.35.1+git.20230315.e1727553:
  * test: update format refs to ffmpeg 6
  * github/workflows: fix failure conditions
  * common/av_common: clean up mp_lavc_set_extradata
  * sub/sd_lavc: properly fill avctx with codecpar values at init
  * sub/lavc_conv: properly fill avctx with codecpar values at init
  * common/av_common: constify mp_codec_params related getters
  * demux_mkv: support ARIB captions
  * player/command: fix mem leak in user-data property; closes #11436
  * vo_gpu_next: compatibility with libplacebo v6.265
  * wayland: make wayland-edge-pixels-pointer default to 16
  * wayland: use correct x/y coordinates for the cursor
  * screenshot: fix segfault when taking a screenshot without video
  * wayland: fix client side resize
  * vo_gpu_next: compatibility with PL_API_VER >= 254
  * vo_gpu_next: use inverse mapping functions to tag screenshots
  * video/out/placebo/utils: add mappings from pl enums to mpv enums
  * video: add missing libplacebo colorspace enums
  * mp_image: assert if src and dst are different in copy_attributes
  * mp_image: copy side data in mp_image_copy_attributes
  * ao_pipewire: use realtime scheduling for data thread
  * loadfile: strongly prefer that all streams are from the same program
  * command: expose hls-bitrate and program-id as track-list subproperties
  * loadfile: report hls_bitrate and program_id in struct track
  * demux: propagate hls_bitrate and program_id in generated caption tracks
  * demux_lavf: report program_id
  * ytdl_hook: only log error when no fallback url available
  * ytdl_hook: init fragment requires other fragments
  * vo: fix race condition with redraw requests
  * ci: separate meson tests and reorganize build steps
  * test: integrate unittests with meson
  * ci: use the same arguments when running the built mpv binary
  * player: remove unittest option
  * test: update ffmpeg format refs
  * zimg: fix MP_CSP_PRIM_CIE_1931 mapping
  * zimg: add ZIMG_TRANSFER_ST428 mapping
  * zimg: set correct primaries for XYZ
  * sws_utils: hardcode output gamma and primaries for XYZ
  * mp_image: fix XYZ gamma and primaries guess
  * vo_gpu: improve XYZ conversion
  * mp_image: be less agressive with clearing color information
  * f_swscale: do not reset color levels to default
  * csputils: add MP_CSP_TRC_ST428 as defined in ST 428-1
  * DOCS/options: mention default value of cursor-autohide
  * DOCS/options: clarify hidpi-window-scale description
  * player: add --auto-window-resize option
  * ra: assert when using params with dimensions
  * sub: add --sub-fonts-dir and --osd-fonts-dir options
  * wayland: request frame callbacks on the topmost surface
  * wayland: deduplicate and cache detection of dmabuf-wayland
  * wayland: use bool type for alpha framebuffer tracking
  * vo_gpu: d3d11_helpers: prefer DXGI_SWAP_EFFECT_FLIP_DISCARD if possible Similar to libplacebo[1], DXGI_SWAP_EFFECT_FLIP_DISCARD is used instead of DXGI_SWAP_EFFECT_FLIP_SEQUENTIAL starting with Windows 10.
  * vf_gpu: initialize depth=1 on target textures
  * video: initialize depth=1 on screenshot textures
  * external_files: recognize jxl and avif files as cover art
  * {console,ytdl_hook}: use the platform property
  * command: add platform property
  * ytdl_hook: don't overwrite force-media-title
  * ytdl_hook.lua: make exec return a single value
  * TOOLS/autocrop.lua: log a more accurate warning
  * audio: remove a duplicate clearing of a struct variable
  * options: change parameter that was forgottin in property transition
  * client API: reintroduce CONF_TYPE_FLAG for type conversion
  * Partially revert "options: remove OPT_FLAG"
  * console: observe osc margins from user-data instead of shared-script-properties
  * osc: set values in user-data in addition to shared-script-properties
  * player: set playlist title to media title if not set already
  * various: fix warning -Wimplicit-const-int-float-conversion
  * vo_gpu_next: fix warning -Wunused-function
  * vo_wayland: fix warning -Wvoid-pointer-to-enum-cast
  * vd_lavc: sort hwdecs without hwdevices last for autoprobing
  * vd_lavc: prioritize mediacodec for hwdec autoprobe
  * video: make csp option definitions private
  * video: make csp equalizer params float
  * vo_gpu: fix newline in log message
  * demux: constify a struct member
  * vo_gpu_next: fix color space hint with target peak override
  * DOCS: clarify that GLX is deprecated
  * options: remove explicit initialization of integers to 0
  * options: remove OPT_FLAG
  * options: transition properties from flag to bool
  * options: transition commands from OPT_FLAG to OPT_BOOL
  * options: transition options from OPT_FLAG to OPT_BOOL
  * input: remove unused struct member
  * DOCS/client-api-changes.rst: move mpv_del_property to 0.36.0
  * various: drop unused #include "config.h"
  * ao_pipewire: drop unused #include "generated/version.h"
  * Vulkan: add configure check for VK_KHR_display extension
  * vo_gpu_next: add --tone-mapping-visualize
  * vo_gpu_next: parse Dolby Vision metadata for dynamic scene brightness
  * mp_image: forward AV_FRAME_DATA_DOVI_RPU_BUFFER side data
  * DOCS: document JPEG XL default effort change
  * Revert "vo_dmabuf_wayland: drop support for linux-dmabuf-v2"
  * video/image_writer: use effort=4 default for JXL screenshots
  * ao_pipewire: fix removal of zeroed hooks on old pipewire
  * vo_gpu_next: allow native CSP screenshots
  * player/screenshot: pass on ability to output native CSP
  * screenshot: explicitly default VOCTRL_SCREENSHOT csp
  * video/image_writer: force sRGB for unsupported formats
  * video/image_writer: add image_writer_flexible_csp
  * vo_gpu_next: tag screenshots with correct colorspace
  * vo_gpu_next: only apply target options in window screenshot mode
  * vo_gpu_next: be explicit about screenshot repr
  * m_property: avoid using a small stack buffer in m_property_do_bstr
  * vo_gpu_next: expose --tone-mapping=st2094-40 and st2094-10
  * vo_gpu_next: support mapping HDR10+ dynamic metadata
  * ao_pipewire: allow usage of global volume control
  * command: only avoid redrawing when old and new osd are both hidden
  * DOCS/options: remove testing note in video-sync-max-factor
  * vf_sub: undeprecate
  * vo_dmabuf_wayland: reject hw formats not supported by compositor
  * video/image_writer: change screenshot-tag-colorspace default to yes
  * vo_dmabuf_wayland: add purgatory list to buffer pool to avoid memory leaks
  * vo_dmabuf_wayland: ensure buffer pool is cleaned at start of uninit
  * vo_dmabuf_wayland: simplify buffer pool reset
  * vo_dmabuf_wayland: only resize when a new frame is about to be drawn
  * DOCS/input: remove experimental note from sub-text
  * ao_pipewire: report linking errors from init()
  * ao_pipewire: add support for exclusive mode
  * ao_pipewire: move stream flags to dedicated variable
  * ao_pipewire: adjust message level based on probing
  * f_hwtransfer: fix leak of framesconstraints
  * image_pool: properly free frames
  * ao_pipewire: remove unneeded goto
  * ao_pipewire: replace opencoded talloc()
  * ao_pipewire: print stream states as string
  * ao_pipewire: remove unnecessary empty lines
  * ao_pipewire: remove opencoded spa_zero()
  * ao_pipewire: remove some unnecessary linebreaks
  * ao_pipewire: reduce message level of unsuccessful connection
  * ao_pipewire: remove unnecessary braces
  * sws_utils: add check for HAVE_ZIMG to suppress warnings
  * vo_gpu_next: add check for PL_HAVE_LCMS
  * hwdec_cuda: fix enum type for semaphore
  * vo_d3d11: do not call MAKEINTRESOURCEW twice
  * osdep/io: add void to mp_penviron
  * demux: remove unused code
  * ao_lavc: remove unused code
  * osdep: add MP_FALLTHROUGH
  * libplacebo: fix enum type cast
  * stats.lua: display HDR peak in nits
  * meson: move vector check inside of meson.build
  * meson: check macos touchbar with has_header
  * meson: check pthread provider with has_function
  * video/image_writer: avoid stripping colorspace info when writing image
  * stream: accept webdav:// and webdavs:// urls
  * ci: pack mingw64 meson build instead of waf
  * ci: separate meson/waf build dirs
  * ci: use meson compile instead of ninja directly
  * ci: do not print compile commands
  * meson: replace check_header with has_header
  * meson: actually use -Werror=format-security
  * hwdec/vaapi: zero-initialize VADRMPRIMESurfaceDescriptor
  * player/video.c: don't resync audio if video is an image
  * vo_lavc: set frame rate on encoder; fixes #11215
  * wayland: add auto choice to wayland-configure-bounds
  * wayland: handle runtime hidpi-window-scale changes correctly
  * wayland: unbreak runtime geometry/autofit changes
  * lua/js: remove user-data helpers
  * lua/js: fix user_data_del util function
  * doc: correct spelling of user-data/user_data JS/lua helpers
  * docs: document new user-data property
  * javascript/defaults: add user_data helpers
  * lua/defaults: add user_data helpers
  * player/command: add user-data property
  * javascript: add mp.del_property()
  * lua: add mp.del_property()
  * libmpv: add mpv_del_property() convenience function
  * player/command: add "del" command
  * m_property: add M_PROPERTY_DELETE
  * player/client: support observing sub-properties
  * options/m_option: support duplicating MPV_FORMAT_BYTE_ARRAY nodes
  * misc/node: add bstr-based variants for map_get() and map_add()
  * misc/json: don't wrap top-level pretty strings/infs in quotes
  * DOCS: Add missing 'not'
  * hwdec_vaapi: close file descriptors even if surface export fails
  * vo_dmabuf_wayland: close file handles when surface export fails
  * vo_dmabuf_wayland: plug leaking file descriptor from solid buffer pool
  * DOCS/compile-windows.md: update MSYS2 packages
  * test/repack.c: skip tests that exceeded maximum allowed ZIMG dimension
  * meson: add missing library dep for egl_angle_lib check
  * vo_opengl/angle_dynamic: simplify symbol renaming to make it more straightforward
  * waf: migrate to version.py
  * ci: migrate MSYS2 build to GitHub Actions
  * wscript: remove MSVC from compiler lookup
  * meson: reuse libmpv objects for cplayer
  * ao_pipewire: align thread name with general conventions
  * audio: simplify implementation of property ao-volume
  * stream/dvb: remove some unused variables
  * x11: remove PresentNotifyMSC from egl/glx/vulkan to fix xpresent timing
  * wayland: add wp-fractional-scale-v1 support
  * wayland: rewrite geometry and scaling handling
  * vo_gpu: implement VO_DR_FLAG_HOST_CACHED
  * vo_gpu_next: implement VO_DR_FLAG_HOST_CACHED
  * vd_lavc: add "auto" choice for vd-lavc-dr
  * vo: add `int flags` to the get_image signature
  * msg: log-file set at mpv.conf: don't ignore early messages
  * msg: log-file buffer size: don't use magic number (no-op)
  * drm: rewrite based around vo_drm_state
  * mp_image: fix XYZ primaries default
  * meson: skip some unneeded macos-specific checks
  * meson: drop feature plain-gl
  * ci: run meson tests
  * meson: limit vaapi checks
  * meson: don't add libmpv and cplayer features to conf_data
  * meson: remove dependency from libmpv to plain-gl
  * meson: add simple test executable for libmpv
  * stream: remove trailing NULL element from stream list
  * hwdec_cuda: drop support for PL_HANDLE_WIN32_KMT
  * wayland: only warn when actually missing idle inhibit support
  * vo: make driver list static
  * vo: remove trailing NULL element from driver array
  * ao: remove trailing NULL element from driver array
  * DOCS/compile-windows.md: update with meson instructions
  * build: officially deprecate waf
  * TOOLS/lua/autoload: improve alphanumeric sorting
  * wayland: store presentation feedbacks in a pool
  * Revert "wayland: dispatch and wait for compositor events in uninit"
  * TOOLS/docutils-wrapper: make executable + alphabetize
  * audio: fix crash during uninit on ao_lavc
  * meson: also search for rst2html with .py extension
  * various: replace abort() with MP_ASSERT_UNREACHABLE() where appropriate
  * various: replace if + abort() with MP_HANDLE_OOM()
  * stream/dvb: drop support for DVB API before 5.8
  * ao_audiotrack: replace malloc with talloc
  * stream/cookies: use stream_read_file()
  * {video,audio}: adjust unsafe strncpy usages
  * video/x11: replace sprintf usage
  * video: replace sprintf usage
  * demux_mf: replace unsafe string functions
  * ra_d3d11: fix incorrect type
  * DOCS: clarify wid casting on Windows
  * vo_dmabuf_wayland: drop support for linux-dmabuf-v2
  * vo_dmabuf_wayland: support panscan and panning
  * ta/README: update link to talloc documentation
  * vo_wlshm: properly support video panscan
  * player: don't force saving start in watch-later-options
  * player: add video-sync=display-tempo
  * player: choose speed of smallest acceptable factor for display sync
  * TOOLS/lua/autoload: optimize performance of natural sorting
  * TOOLS/lua/autoload: further optimize the natural sorting
  * wayland: make vo_wayland_reconfig a bool
  * wayland: cleanup on vo_wayland_init error
  * vo: change vo_platform_init to bool
  * vo_wlshm: cleanup on failure
  * vo_dmabuf_wayland: goto err instead of returning
  * vulkan: fix build error for 32bit builds with clang
  * meson: dynamically compute dependencies for manpage and html build
  * TOOLS/umpv: support shell-quotes in $MPV
  * demux: new packet should not point to source buffer when copying data
  * demux: actually initialise packet buffer when creating new packet
  * version.py/version.sh: bump copyright year
  * demux: boost read EBU R128 gain values to ReplayGain's reference level
  * wayland: dispatch and wait for compositor events in uninit
  * wayland: initalize display_fd as -1
  * wayland: consistently employ use_present
  * draw_bmp: ensure last slice width is less than total width
  * vo: hwdec: fix drmGetDeviceNameFromFd2() related memory leak
  * hwdec_drmprime: fix memory leak
  * ao_coreaudio: use AudioUnitReset as ao_driver.reset to prevent long restart
  * vo_opengl: do not blindly reject all Microsoft's OpenGL implementations
  * demux: add --demuxer-hysteresis-secs option to save power with caching
  * external_files: recognize webp files as cover art
  * x11: add modesetting to the xpresent whitelist
  * build: add configure test for POSIX shm for the sake of vo_kitty
  * demux: replace deprecated usage of stack allocated AVPackets
  * audio: reset pull AO at end of file
  * vo_kitty: Introduce modern sixel alternative
  * external_files: set log level for potential files to trace
  * hwdec/d3d11va: fix a possible memory leak
  * filter_kernels: fix kaiser
  * man/vo: Typo
  * man/vo: Correct --vo-sixel-buffered
  * vo_sixel: Implement write() loop
  * vo_sixel: Rename draw-clear -> config-clear
  * osdep/terminal.h: Rename screen buffer controls
  * vo_sixel: Alias/deprecate exit-clear -> alt-screen
  * vo_sixel: Make buffering optional
  * man/vo: Fix rendering error due to non-printables
  * DOCS/interface-changes: Add --vo-sixel-draw-clear
  * Revert "ao_pipewire: deactivate stream at end of playback"
  * vo_sixel: Buffer full output sequence
  * vo_sixel: Use write(2) on POSIX platforms
  * vo_tct: Use newer options API
  * vo_sixel: Move user options to struct
  * vo_sixel: Add option to skip clear while drawing
  * osdep/terminal: Move common esc codes to terminal.h
  * vo_sixel: Use the alternate buffer to restore term
  * vo_tct: Use the alternate buffer to restore term
  * ao_pipewire: deactivate stream at end of playback
  * ao_pipewire: clean up when hotplug_init fails
  * ao_pipewire: destroy context on connection failure
  * ao_pipewire: free properties on failure
  * vd_lavc: Set AV_HWACCEL_FLAG_UNSAFE_OUTPUT flag
  * hwdec_drmprime: support yuv420p format
  * ao_coreaudio: use device's nominal sample rate for latency properties
  * player: add window-id property
  * ffmpeg: update to handle deprecation of `av_init_packet`
  * sws_utils: update to handle deprecation of `avcodec_enum_to_chroma_pos`
  * vd_lavc: update to handle deprecation of `pkt_duration`
  * ffmpeg: increase minimum required version to 4.4
  * wayland: check for resize/move in touch event first
  * osc: don't spam window-controls bindings on every render
  * ao_pipewire: log sample queueing
  * TOOLS/umpv: prefer $XDG_RUNTIME_DIR
  * vo_gpu_next: don't flush cache on OSD update
  * meson: fix stdatomic detection on bsd
  * lcms: fix validate_3dlut_size_opt
  * lcms: always parse lcms2-related options
  * vo_dmabuf_wayland: use single-pixel-buffer-v1
  * wlbuf_pool.h: add headers for forward declarations
  * meson: unbreak dl check on BSDs without libdl
  * meson: prepend MPV_CONFDIR path with prefix
  * vo_gpu_next: fix undefined behavior on alpha-first formats
  * wayland: also log refresh rate on surface entrance
  * drm: remove legacy API
  * wayland: add support for content-type protocol
  * player/video: add VOCTRL_CONTENT_TYPE
  * player/main: log libplacebo version if built with it
  * common/av_log: move general FFmpeg version before library versions
  * vo: hwdec: remove legacy_names
  * player: add --force-render option
  * wayland: error out if essential protocol support is missing
  * meson: fix capitalization of "OpenGL"
  * ao_pipewire: log version information and metadata
  * DOCS: update release policy to match reality
  * Update VERSION
- Refresh mpv-make-ffmpeg-version-check-non-fatal.patch
* Wed Feb  8 2023 jaime.marquinez.ferrandiz@fastmail.net
- Update to version 0.35.1+git.20230128.140ec21c:
  * ao_pipewire: log version and other useful debug info
  * wayland: error out if essential protocol support is missing
  * wayland: also log refresh rate on surface entrance
  * vo_gpu_next: fix undefined behavior on alpha-first formats
  * meson: prepend MPV_CONFDIR path with prefix
  * meson: unbreak dl check on BSDs without libdl
  * lcms: fix crash with lcms2-related options if lcms is disabled
  * meson: fix stdatomic detection on bsd
  * osc: don't spam window-controls bindings on every render
  * wayland: check for resize/move in touch event first
  * ao_coreaudio: use device's nominal sample rate for latency properties
  * ao_pipewire: properly clean up resources
  * filter_kernels: fix kaiser
  * hwdec/d3d11va: fix a possible memory leak
  * external_files: set log level for potential files to trace
  * vo_opengl: do not blindly reject all Microsoft's OpenGL implementations
  * ao_coreaudio: use AudioUnitReset as ao_driver.reset to prevent long restart
  * hwdec_drmprime: fix memory leak
  * vo: hwdec: fix libdrm-related memory leak
  * draw_bmp: ensure last slice width is less than total width
  * wayland: dispatch and wait for compositor events in uninit
  * demux: boost read EBU R128 gain values to ReplayGain's reference level
  * version.py/version.sh: bump copyright year
  * vulkan: fix build error for 32bit builds with clang
  * vo_wlshm: cleanup on failure
  * ra_d3d11: fix incorrect type
  * meson: also search for rst2html with .py extension
  * audio: fix crash during uninit with ao_lavc
  * mp_image: fix XYZ primaries default
  * vd_lavc: add "auto" choice for vd-lavc-dr
  * vo: implement VO_DR_FLAG_HOST_CACHED
  * x11: fix issue with xpresent timing feedback
- Refresh mpv-make-ffmpeg-version-check-non-fatal.patch
* Fri Dec 23 2022 mia@0x0.st
- Update to version 0.35+git.20221222.657fd280:
  * audio: reset pull AO at end of file
  * vo_kitty: Introduce modern sixel alternative
  * external_files: set log level for potential files to trace
  * hwdec/d3d11va: fix a possible memory leak
  * filter_kernels: fix kaiser
* Tue Dec 20 2022 mia@0x0.st
- Update to version 0.35+git.20221220.d5c3b9d9:
  * man/vo: Typo
  * man/vo: Correct --vo-sixel-buffered
  * vo_sixel: Implement write() loop
  * vo_sixel: Rename draw-clear -> config-clear
  * osdep/terminal.h: Rename screen buffer controls
  * vo_sixel: Alias/deprecate exit-clear -> alt-screen
  * vo_sixel: Make buffering optional
  * man/vo: Fix rendering error due to non-printables
  * DOCS/interface-changes: Add --vo-sixel-draw-clear
  * Revert "ao_pipewire: deactivate stream at end of playback"
  * vo_sixel: Buffer full output sequence
  * vo_sixel: Use write(2) on POSIX platforms
  * vo_tct: Use newer options API
  * vo_sixel: Move user options to struct
  * vo_sixel: Add option to skip clear while drawing
  * osdep/terminal: Move common esc codes to terminal.h
  * vo_sixel: Use the alternate buffer to restore term
  * vo_tct: Use the alternate buffer to restore term
  * ao_pipewire: deactivate stream at end of playback
  * ao_pipewire: clean up when hotplug_init fails
  * ao_pipewire: destroy context on connection failure
  * ao_pipewire: free properties on failure
  * vd_lavc: Set AV_HWACCEL_FLAG_UNSAFE_OUTPUT flag
  * hwdec_drmprime: support yuv420p format
  * ao_coreaudio: use device's nominal sample rate for latency properties
  * player: add window-id property
  * ffmpeg: update to handle deprecation of `av_init_packet`
  * sws_utils: update to handle deprecation of `avcodec_enum_to_chroma_pos`
  * vd_lavc: update to handle deprecation of `pkt_duration`
  * ffmpeg: increase minimum required version to 4.4
  * wayland: check for resize/move in touch event first
  * osc: don't spam window-controls bindings on every render
  * ao_pipewire: log sample queueing
  * TOOLS/umpv: prefer $XDG_RUNTIME_DIR
  * vo_gpu_next: don't flush cache on OSD update
  * meson: fix stdatomic detection on bsd
  * lcms: fix validate_3dlut_size_opt
  * lcms: always parse lcms2-related options
  * vo_dmabuf_wayland: use single-pixel-buffer-v1
  * wlbuf_pool.h: add headers for forward declarations
  * meson: unbreak dl check on BSDs without libdl
  * meson: prepend MPV_CONFDIR path with prefix
  * vo_gpu_next: fix undefined behavior on alpha-first formats
* Sat Nov 19 2022 Mia Herkt <mia@0x0.st>
- Use Meson for build where possible as waf will be dropped in a
  future version
* Sat Nov 19 2022 mia@0x0.st
- Refresh mpv-make-ffmpeg-version-check-non-fatal.patch
- _service: obs_scm -> obs_tar
- Do not require libsixel and mujs where no appropriate versions
  are packaged
- Vulkan requires recent libplacebo; disable on Leap <= 15.3
- Update to version 0.35+git.20221118.d3a61cfe:
  * wayland: also log refresh rate on surface entrance
  * drm: remove legacy API
  * wayland: add support for content-type protocol
  * player/video: add VOCTRL_CONTENT_TYPE
  * player/main: log libplacebo version if built with it
  * common/av_log: move general FFmpeg version before library versions
  * vo: hwdec: remove legacy_names
  * player: add --force-render option
  * wayland: error out if essential protocol support is missing
  * meson: fix capitalization of "OpenGL"
  * ao_pipewire: log version information and metadata
  * DOCS: update release policy to match reality
* Sun Nov 13 2022 ecsos@opensuse.org
- Update to version 0.35+git.20221112.2f747341:
  * Update VERSION
  * Release 0.35.0
  * meson: fix macos-touchbar check
  * github/workflows: force deletion of existing upstream python symlinks on macOS
  * vo_gpu_next: add tunable shader parameters
  * vo_gpu: mark --gamma-factor and --gamma-auto with deprecation warnings
  * wayland, x11: fix possibly unsafe bstr usage
  * ao_pipewire: reload ao on stream disconnect
  * ao_pipewire: explicitly remove stream hook
  * ao_pipewire: log generic stream errors
  * Revert "ao/audiounit: include AVAudioSession buffer in latency calc"
  * vo_dmabuf_wayland: improve error handling exporting VA surface
  * hwdec_vaapi: only set VADisplay resource if entire init process has succeeded
  * github/workflows: remove seccomp disablement
  * github/workflows: bump linux jobs to Ubuntu 22.04 base VM
  * github/workflows: move all build jobs to checkout V3
  * github/workflows: remove xcode 13.0 to xcode 13.1 override
  * github/workflows: remove macOS 10.15 image usage
  * sd_ass: never mangle colours on RGB video
  * meson: move dmabuf-wayland specific files under the right check
  * gpu/context: properly guard wldmabuf context
  * console: add history deduplication
  * github/workflows: remove pip usage in mingw CI
  * vo_gpu_next: set background transparency
  * ci: upload resulting binary of mingw64 build
  * ci/mingw64: refresh build scripts
  * ytdl_hook: reverse order of tracks
  * demux/codec_tags: support more WAVEFORMATEXTENSIBLE tags
  * wayland_common: always zero out presentation context when destroying it
  * wayland: correct braindead comment (no-op)
  * wayland: hack around presentation_feedback weirdness
  * wayland: free dmabuf_feedback object
  * test: update to reflect that Vulkan is a generic format again
  * filters/f_hwtransfer: remove VAAPI <-> Vulkan mapping for now
  * build: add an additional check for wayland-protocols 1.24
  * meson: add more hardcoded values to configuration
  * meson: use 'dl' instead of 'libdl' in find_library
  * ci: use meson setup build instead of meson build
  * ao_coreaudio: specify UTF-8 as text encoding for CFString conversions
  * options: log profile name if there is no restore data
  * console: respect the top margin shared script property
  * vo_dmabuf_wayland: use special ra_ctx_create_by_name
  * vo_dmabuf_wayland: load all hwdecs in preinit
  * wayland: always do a display_roundtrip at the end of init
  * github/workflows: print error logs on freebsd
  * ci/build-freebsd.sh: remove nonexistent option
  * vo_dmabuf_wayland: fix DRM builds with no VAAPI
  * video/out/wayland_common: adjust decoration disagreement log level
  * video/out/wayland_common: clear decoration request even if compositor disagrees
  * video/out/wayland_common: don't pass a negative of border flag into ternary
  * video/out/wayland_common: make decoration state usage explicit
  * ao_pipewire: compatibility for libpipewire 0.3.19
  * ci: require pipewire to be enabled for Tumbleweed Linux builds
  * wayland: bump dmabuf protocol to version 4
  * vo_vaapi_wayland: remove, as it is superceded by vo_dmabuf_wayland
  * vo_dmabuf_wayland: wayland VO displaying dmabuf buffers
  * wayland: clean wp_presentation_feedback in discard callback to avoid leak
  * build_image_converter - use full image format list to create hw_upload
  * mp_imgfmt: move DRMPRIME format to end of enum
  * DOCS: document E to cycle through Editions
  * ao: promote ao_pipewire
  * ao_pipewire: test for session to contain audio sinks
  * ao_pipewire: init_boilerplate(): simplify errorhandling
  * TOOLS/lua/autoload: fix incorrect duplicate file loading behavior
  * audio/format: fix Type 'struct entry' has incompatible definitions in different translation units
  * vo_gpu/hwdec: add NULL check for legacy_name
  * hwdec_aimagereader: fix incorrect return values
  * demux_mkv: add AVS2 and AVS3 to tag list
  * wscript: remove some bogus configure options
  * demux_mf: add support for QOI, PHM and HDR images
  * f_hwtransfer: allow hw uploads to implicitly convert formats
  * f_hwtransfer: accept non-power-of-2 hw uploads
  * hwdec/dmabuf_interop_gl: work-around implicit rgba swizzling
  * f_hwtransfer: get rid of the shit list
  * hwdec/vaapi: improve probing of supported sw formats
  * vo_gpu_next: fix crash on uninit after startup failure
  * sd_ass: improve handling of subtitles with unknown duration
  * DOCS: fix minor typo with keep-open description
  * draw_bmp: fix out of bounds access in mark_rect
  * vo_gpu/hwdec: rename and introduce legacy names for some interops
  * x11: fix --on-all-workspaces option
  * vo_gpu_next: vulkan: libplacebo: unify log prefix
  * github/workflows: explicitly install Xinerama on FreeBSD
  * x11: fix a couple of memory leaks
  * ao_pipewire: allow specification of remote name
  * ao_pipewire: small cleanups and restructring
  * osc: scale rendered aspect ratio with window aspect ratio
  * wayland: correctly handle non-CLOCK_MONOTONIC clocks
  * vulkan: remove --vulkan-disable-events
  * vo: hwdec_aimagereader: add missing image format specifier
  * vo_gpu: hwdec: add Android hwdec utilizing AImageReader
  * DOCS: deprecate --gamma-factor and --gamma-auto
  * vo_gpu_next: respect --blend-subtitles=<yes/no>
  * ao_pipewire: don't try to lock nonexistent loop
  * ao_pipewire: use target.object
  * mp_image: strip DoVi metadata that requires an EL
  * manpage: document bt.2390 parameter
  * vo_gpu_next: fix screenshots of rotated sources
  * DOCS/man/vf.rst : replace the outdated syntax
  * vo_gpu_next: use static assert for array size
  * vo_gpu_next: update render_info for upstream API change
  * vo_gpu_next: implement --video-output-levels
  * TOOLS/lua/autoload: add various extra file extensions
  * TOOLS/lua/autoload: alphebatize auto-loaded file extensions
  * ytdl_hook: use subtitle `name` as title if available
  * af_scaletempo2: fix crash when the number of channels increases
  * build: update waf to 2.0.24
  * f_hwtransfer: mp_image_pool: support HW -> HW mapping
  * f_autoconvert: f_hwtransfer: support HW -> HW uploads
  * filters: lavfi: allow hwdec_interop selection for filters
  * filters: support loading new hwdec_interops from filters
  * vo: hwdec: do hwdec interop lookup by image format
  * demux_lavf: extract is_image function
  * demux_lavf: detect avif images
  * DOCS/man/options.rst: replace some legacy single-hyphen syntax
  * vo_gpu_next: support error diffusion dithering
  * sub: use Unicode linebreaking for non-ASS subs and OSD
  * ao_audiounit: get the channel layout from the AU itself
  * mac: avoid unnecessary unsafe conversions; fixes crash in debug builds
  * TOOLS/lua/autoload: add `m2ts` extension * `.m2ts` used for the Blu-ray disc container file format
  * ytdl_hook: simplify exclude option parsing
  * vo_gpu_next: only require full pixel byte alignment
  * vo_gpu_next: implement ICC 3DLUT caching
  * vo_gpu_next: use correct pixel size when mapping formats
  * ao_pipewire: listen to hotplug events
  * ao_pipewire: use proper hotplug init APIs
  * ao_pipewire: create is_sink_node helper
  * audio: list devices for all AOs with hotplug_init
  * audio: try to use playback AO as hotplug AO first
  * ta: increase size of names printed
  * ao_pipewire: handle AOCONTROL_UPDATE_MEDIA_ROLE
  * audio: add AOCONTROL_UPDATE_MEDIA_ROLE
  * ao_pipewire: fix indent
  * repack: add repacker for ccc16x16 formats
  * mpv.metainfo.xml: add XDG appstream metadata manifest
  * DOCS: Mention "mono" audio channels option
  * DOCS/libmpv: fix typo in linkage section
  * w32: fix typo in F23 mapping
  * vo_gpu_next: fix typo affecting --target-trc option
  * macos: add support for F13-F20 keys
  * w32: add support for F13-F24 keys
  * x11: add support for F13-F24 keys
  * wayland: add support for F13-F24 keys
  * input: add function keys F13-F24
  * ad_lavc: strip non-normalized floats
  * vo_gpu_next: display subtitles without video stream
  * DOCS/options: update vd-lavc-skiploopfilter, skipidct and related descriptions
  * DOCS/mpv: remove spaces at EOL, ensure 80 cols
  * DOCS/mpv: added COMMAND INTERFACE refs to INTERACTIVE CONTROL
  * ao_pipewire: for_each_sink(): report errors
  * meson: fix condition for enabling vaapi-egl
  * meson: fix libplacebo check
  * audio: fix lack of reinitialization on format change with pull AOs
  * player/audio: remove explicit drain on EOF
  * ao_pipewire: make sure not to exceed the available buffer
  * audio: don't try to drain non-existent AO
  * vo_gpu_next: pass GL get_proc_addr pointer to libplacebo
  * ao_pipewire: test on FreeBSD
  * mpv.desktop: add RIST protocol to desktop entry
  * osxbundle: add RIST protocol support to app metadata
  * stream_lavf: enable RIST protocol support via ffmpeg
  * ao_pipewire: restructure logic a bit
  * ao_pipewire: only try to read requested data
  * ao_pipewire: report all available info about chunk
  * ytdl_hook: improve track detection
  * misc/random: add xoshiro random number implementation
  * meson: fix the build-date option
  * meson: fix building without gl
  * meson: consistently use feature['foo']
  * meson: refactor generating config.h
  * meson: disable dvdnav by default
  * meson: reduce dictionary usage
  * meson: add comment clarifying windows-internal-pthreads
  * ytdl_hook: consistant behavior for single format
  * wayland: add support for configure bounds
  * x11: fix display-{width,height} calculation
  * DOCS/options: correct wayland-disable-vsync option
  * ytdl_hook: fix default track for single format
  * github/workflows: auto-update freebsd-vm within major version
  * drm_common: remove hard dependency on drmIsKMS()
  * context_drm_egl: skip page flip wait on error
  * gpu/hwdec: reorder `drmprime` below `drmprime_drm`
  * video/drmprime: fix use-after-free
  * hwdec/drmprime: fix build
  * hwdec/dmabuf_interop: Properly prefix `priv` struct
  * hwdec/drmprime: Fix small issues
  * audio: drain ao on EOF
  * hwdec/drmprime: add drmprime hwdec-interop
  * ao_pipewire: tell audio server about number of queued samples
  * man: remove unhelpful language
  * ao_pipewire: use mpv logging
  * hwdec/dmabuf_interop_gl: support basic multi-plane formats
  * hwdec/dmabuf_interop: use AVDRMFrameDescriptor to describe dmabufs
  * hwdec/dmabuf_interop: refactor out hwdec_vaapi dependencies
  * hwdec/vaapi: rename interops to reflect more general use
  * af_rubberband: add new engine option in rubberband 3.0.0
  * drm_common: skip cards that don't support KMS for autodetection
  * drm: avoid drmModeAtomicCommit races by blocking
  * video: remove unnecessary code
  * ytdl_hook: fix playlist index extraction
  * ci: bump macos runner version
  * wayland: add missing newline in wayland_common
  * hwdec_vaapi_pl: support simple multi-plane image formats
  * vo_gpu_next: fix screenshots on single-frame files
  * vo_gpu/d3d11: fix VRAM leak
  * osc.lua: add osc-tcspace script option
  * osc.lua: add osc-unicodeminus script option
  * vo_gpu_next: don't crash on !frame->current
  * ytdl_hook: always set HTTP headers
  * libplacebo: fix compatibility with libplacebo >= 5
  * github/workflows: upgrade FreeBSD to 13.1
  * vo_gpu: fix 3DLUT precision
  * ao_pipewire: prevent deprecation warning for pw_stream_get_time()
  * ao_pipewire: pipewire uses linear volume
  * ao_pipewire: don't access core after disconnect
  * ao_pipewire: zero listeners
  * ao_pipewire: support ao-volume on non-stereo channel layouts
  * DOCS/encoding: remove the legacy option syntax
  * drm_prime: fix newline in error message
  * meson: fix rst2html command
  * context_x11egl: remove supposed transparency fix
  * DOCS: fix typo
  * DOCS/osc: fix option "showidlescreen" -> "idlescreen" This option was added in mpv-player@ec236f7, but its name in the document description is incorrect
  * meson: add a summary at the end of configuration
  * vo_gpu_next: implement --cscale
  * swresample: don't forcibly clip on every conversion
  * js: key bindings: ensure priorities for same-key - again
  * x11: avoid XPresent API calls when it's not needed
  * lua: command_native_async: make the callback optional
  * lua: command_native_async: always callback a-sync
  * x11: add --x11-present option
  * x11: add nouveau to the xpresent whitelist
  * x11: correct provider detection logic
  * vo_vaapi_wayland: remove vaapi format query as formats are never used
  * meson: remove pointless d3d11 dictionary
  * x11: replace strcasestr usage with bstr
  * github/workflows: install libxpresent on freebsd
  * x11: support xorg present extension
  * x11: use xrandr providers for driver detection
  * vo: move wayland presentation to separate files
  * meson: use require when checking for vdpau
  * ci/build: Do not manually install Meson in openSUSE container
  * meson: rearrange library dependency order to avoid crash with fontconfig
  * vo_vaapi_wayland: only attach solid buffer once to main surface, on creation
  * vo_vaapi_wayland: remove unnecessary subsurface sync/desync in resize
  * ci/build-mingw64: enable test building
  * ci/build-mingw64: bump dependencies
  * ci/build-mingw64: switch to fossils directory for zlib
  * ci/build-tumbleweed: attempt to enable unit tests in CI
  * test/chmap: start adding AVChannelLayout unit tests
  * audio/chmap: add mp_iterate_builtin_layouts
  * f_lavfi: switch to AVChannelLayout when available
  * ad_lavc: switch to AVChannelLayout when available
  * af_lavcac3enc: switch to AVChannelLayout when available
  * af_lavcac3enc: refactor chmap adding into its own function
  * ao_lavc: switch to AVChannelLayout when available
  * demux_lavf: switch to AVChannelLayout when available
  * common/av_common: switch to AVChannelLayout when available
  * audio/aframe: switch to AVChannelLayout when available
  * audio: add AVChannelLayout helpers to convert from/to mp_chmap
  * wayland: set appid before initial surface commit
  * wayland_gl: fix a typo
  * wayland_gl: wait until resize to create egl_window
  * DOCS/options: fix incorrect labelling of hr-seek default
  * sub: jsre filter: abort init early on empty filter list
  * ci/mingw64: add git libplacebo for gpu-next
  * github/workflows: move mingw CI to ubuntu 22.04
  * ci/mingw64: make meson crossfile global
  * wayland_gl: use wl->scaling when creating egl_window
  * wayland: rearrange initialization logic
  * player: add tiff/tif (TIFF) to list of image extensions
  * player: add jxl (JPEG XL) to list of image extensions
  * wayland: remove some unneeded lines from reconfig
  * vo_gpu_next: fix OSD rendering of screenshots
  * meson: add internal arg to wayland-protocols' get_variable()
  * osc.lua: add idlescreen and osc-idlescreen
  * video/out/dither: remove custom index_t typedef
  * wayland: force vo_vaapi_wayland scaling to 1
  * DOCS/interface-changes: mention vaapi-wayland vo
  * vo: move allocate_memfd method to wayland_common
  * vo_vaapi_wayland/wayland_common: code style fixes
  * wayland: use mp_tag_str not drm_format_string
  * vo: allow vaapi_wayland and vaapi_x11 to coexist
  * wayland: don't depend on the order of global announcements
  * vo: add new vaapi-wayland driver
  * demux: stop iterating over demuxers as soon as a match is found
  * osc.lua: fix crash when calling osc-tracklist while idle
  * player: check for argv before printing help text
  * player: set EOF when seeking to end with keep-open
  * various: remove trailing whitespace
  * wayland: use wl_output v4 for display-names
  * lua: avoid rare memory leak in mp.join_path
  * client API: always export symbols on windows
  * stream_lavf: add support for ipfs and ipns
  * meson: compile mpv.exe as a win32 gui application
  * context_drm_egl: support monitor par
  * github/workflows: add macOS 12 build
  * video/image_writer: tag colorspace in AVCodecContext
  * DOCS/input: fix typo "NANME" -> "NAME"
  * console.lua: don't render a 2nd cursor on the OSC
  * video/image_writer: fix high-depth JPEG XL screenshots
  * build: add avcodec jpegxl dependency versions
  * demux: add support for r128 replaygain tags
  * DOCS/ao: remove only usage of git.io link shortening service
  * wayland: use wl_surface_damage_buffer
  * DOCS/options: properly capitalize JPEG XL
  * video/image_writer: add Jpeg XL screenshots
  * various: fix typos
  * vo_gpu_next: avoid 0x0 resizes
  * github/workflows: workaround git permissions error
  * DOCS/options: update the --load-osd-console documentation
  * DOCS/input: update the ASS tags documentation URL
  * options: make --cover-art-auto=exact the default
  * player: add cover-art-whitelist option
  * DOCS: fix the typo of --sub-justify
  * DOCS: correct --sub-shadow-color
  * DOCS/{mpv,options}: document the watch later functionality
  * vo_wlshm: use draw_frame instead of draw_image
  * mpv.desktop: add japanese translation
  * ci: switch Tumbleweed build to openSUSE container registry
  * vd_lavc: fixup unchecked usage of AV_CODEC_EXPORT_DATA_FILM_GRAIN
  * vd_lavc: fix decoder initialization when no VO is available
  * vd_lavc: remove duplicate vd_ffmpeg_ctx pointer from init_avctx
  * wayland: use wl_output v4 for --fs-screen-name
  * x11: avoid wasteful rendering when possible
  * player: rearrange video sync opts/enums/defines
  * wayland: unify visibility checking code
  * vo_gpu/d3d11: add message ID based log level mapping
  * vo_gpu/d3d11: mimic libplacebo backbuffer usage
  * vo_gpu/d3d11: enable receival of color depth without active backbuffer
  * vo_gpu/d3d11: add helper function to get ra_format from DXGI_FORMAT
  * vo_gpu_next: switch to unpooled hwdec mapping
  * x11: fix screen-name option
  * mpv.desktop: add turkish translation
  * options.lua: remove unused function
  * options: add osd-playing-msg-duration
  * egl_helpers: request at least 8 alpha bits if necessary
  * DOCS/input: mark chapter-list as writable
  * drm: context_drm_egl: add support for enabling VRR
  * vd_lavc: add vo caps and option to set GPU film grain application
  * vo_gpu_next: apply film grain if such metadata is present
  * vf_format: support forwarding/stripping film grain metadata
  * mp_image: support film grain parameters
  * vd_lavc: hide a deprecation warning in already handled compatible code
  * sub/osd: use atomic for osd_state.force_video_pts
  * osdep/atomic: add mp_atomic_double
  * Revert "vo_gpu_next: remove unnecessary dependency"
  * ao_pipewire: Do not hold thread lock during loop stop
  * ao_pipewire: fix resource lifetimes
  * vo_gpu_next: remove unnecessary dependency
  * lua: use correct chunkname when loading script files
  * vo_gpu[_next]: hwdec: fix logging regression when probing
  * common/av_log: explicitly include version.h for required libraries
  * vo_gpu_next: also include stride alignment in DR size
  * vulkan: correctly inherit proc_addr pointer
  * ao_sndio: fix parentheses warning
  * client API: also export mpv_stream_cb_add_ro
  * vo_gpu: hwdec_vaapi: Improve logging when probing surface formats
  * DOCS/options.rst DOCS/vo.rst: Update discussion of hwdec usage
  * vo_gpu_next: fix crash when disabling DR at runtime
  * vo_gpu_next: don't leak mpi on failed upload
  * vo_gpu_next: properly keep track of DR allocations
  * hwdec: warn on unsupported hwdec option value
  * vo_gpu_next: don't allocate dr_buf as part of the AVBufferRef
  * hwdec: fix out-of-date preprocessor variable name
  * ytdl_hook.lua: consider any subprocess status != 0 as error
  * vo_gpu_next: add D3D11 RA texture wrapping/unwrapping for hwdec
  * vo_gpu_next: add support for hardware decoding
  * manpage: add vo_gpu_next wiki link to manpage
  * vo_gpu_next: configure the VO queue size dynamically
  * vo_gpu_next: expose EGLDisplay to pl_gpu
  * vo_gpu: move hwdec loading code to common helper
  * hwdec: release images as soon as possible after mapping
  * hwdec_vaapi_vk: rename to vaapi_pl
  * hwdec_vaapi_gl: properly zero initialize priv struct
  * filters: Re-add vavpp deinterlacing auto-filter
  * ytdl_hook: fix url_is_safe to match URL protocols properly
  * vo_gpu_next: remove/simplify plane flipping hacks
  * vo_gpu_next: avoid rendering subtitles as HDR/wide gamut
  * mp_image: fix mp_image_plane_w/h
  * stats.lua: page 2 - frame timing: use fixed display order
  * stats.lua: graphs: fix bad rendering due to division by 0
  * vo_gpu_next: refactor subtitle rendering
  * options: add always to stop-screensaver
  * DOCS/input: document subprocess more clearly
  * DOCS/input: fix typo
  * vo_gpu: hwdec: load hwdec interops on-demand by default
  * ao_pipewire: fix ao-volume handling
  * vo_gpu_next: don't crash on negative plane strides
  * vo_gpu: d3d11_helpers: don't create UNORDERED_ACCESS backbuffers in Win7
  * meson: remove horrifying macos luajit hack
  * github/workflows: use lua 5.1 on macos
  * DOCS/mpv: improve vf=rotate examples
  * wayland: partially fix drag and drop handling
  * ao_pipewire: validate pod creation
  * ao_pipewire: add support for device selection
  * vo_gpu_next/context: get graphics API-specific contexts from pl_gpu
  * vf_format: simplify frame type checking after addition of DoVi option
  * vo_gpu: hwdec_vaapi: Don't probe formats for irrelevant endpoints
  * ci/appveyor: fix package install line
  * osc.lua: seekbar hover: speed-up chapter access
  * js: utils.get_user_path: make wrapper of expand-path
- Change source from cpio/tar to tar.xz to reduce the source code
  size by a factor of 4.
- Update waf to version 2.0.24
- Set rubberband to version 3.0.0 which is need for optional dependencies.
- Remove --enable-pipewire because it is now autodetected.
  You can now only disable.
- Disable pipwire under Leap because of build error.
- Enable openal, sixel.
- Enable mujs for Leap >= 15.4.
- Enable wayland for Leap >= 15.4.
- If libavif is installed default at build time it must have version >= 0.11.1
- Fix rpmlint filename-too-long-for-joliet.
* Tue Jun  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop pkgconfig(libkms) BuildRequires: this has been removed from
  latest libdrm.
* Sat Feb  5 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.34.1+git.20220203T182214.5d31c7310c:
  * libplacebo: switch to new target format API
  * libplacebo: switch to new GPU limits APIs
  * libplacebo: switch to v4 naming convention
  * libplacebo: update log helpers
  * vo_gpu_next: create shader cache dir if missing
  * wayland: always start rendering after a resize
  * filter kernels: add cosine window
  * vo_gpu_next/context: common'ize things that would be common for non-vulkan
  * auto_profiles.lua: don't warn if profile-restore=default
* Sun Jan 30 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.34.1+git.20220129T121245.4d3ebb9d83:
  * meson: add version check to wayland-protocols
  * wayland: always resize when scale changes on surface enter
  * wayland: support extra mouse buttons
  * wayland: handle 0x0 resizes correctly
  * x11: sanitize window title to UTF-8 for EWMH
  * wayland: sanitize toplevel title to UTF-8
  * ao_sndio: audio output added
  * options: only apply sub-visibility to primary subs
  * Revert "options: add --sub-visibility=<primary-only|secondary-only>"
  * options: add --sub-visibility=<primary-only|secondary-only>
  * player: add thd (TrueHD) to whitelist of audio extensions
  * player: fix parentheses warning with &&
* Wed Jan 19 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.34.1+git.20220117T134844.22b0bac28e:
  * native pipewire AO
  * Dolby Vision support
  * player: fix autofit/geometry related segfault
  * ao_oss: add missing PATH_DEV_MIXER define
  * egl_helpers: fix context creation if GLES 3 is not available
  * audio: stop corrupting audio on underreads
  * wayland: fix a potential segfault on surface enter
  * vo_gpu: opengl: fix wrong glMemoryBarrier call
  * vo_gpu: opengl: create context at version 4.4 again
  * af_lavcac3enc: fix memory leak on no-op
  * subprocess: unblock/reset signals before running child process
  * wayland: avoid doing unneccesary window resizes
  * See https://github.com/mpv-player/mpv/compare/9ca9066d05..22b0bac28e
    or https://git.srsfckn.biz/mpv/log/?qt=range&q=9ca9066d05..22b0bac28e
    for the complete changelog.
* Sun Nov 21 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.34.0+git.20211101T154439.9ca9066d05:
  * input.conf syntax: support custom quotes in `XstringX` form & single quotes
  * ao_oss: readd OSSv4 audio output, default on *BSD
  * osc: seekbar hover/drag: display target chapter at the OSC title
  * stats.lua: add page 4 with a list of active key bindings
  * sub: add --sub-filter-jsre (JS regex)
  * vo_rpi: restore fullscreen handling
  * vo_tct: add resize capability
  * ytdl_hook.lua: search for yt-dlp by default (preferred over youtube-dl)
  * vo_sixel: many fixes and improvements
  * filters: switch from scaletempo to scaletempo2, used for speed option
  * audio/vo_pulse: fix various edge cases and issues
  * stats.lua: move internal performance info from page 4 to page 0
  * command: don't hardcode command lists to be repeatable
  * vo_gpu: drop support for libplacebo older than v3.104.0
  * See https://github.com/mpv-player/mpv/compare/bc9d556f3a..9ca9066d05
    or https://git.srsfckn.biz/mpv/log/?qt=range&q=bc9d556f3a..9ca9066d05
    for the complete changelog.
* Thu Jul  1 2021 ismail@i10z.com
- Update to version 0.33.1+git.20210630T163736.f2afae55e9:
  * wayland: refactor surface scaling
  * sub: fix subs/lyrics on music files with sub-past-video-end=no
  * wayland: fix wl_surface_set_buffer_scale usage
  * wayland: always be sure to initially try to render
  * wayland: remove unused includes
  * wayland: handle app id option less stupidly
  * wayland: reorganize wayland common code
  * stats.lua: add scaled resolution
  * DOCS: fix typo on seekbarkeyframes
  * TOOLS/lua/autoload: load files even if current file is hidden
  * TOOLS/lua/autoload: add ignore_hidden option
  * player: fix property name
  * lua: idle observers: ensure timers are up-to-date
  * lua: timers: don't block forever with slow callbacks
  * sub: by default, don't render timestamps after video EOF
  * player: change cover-art-auto behavior
  * js: idle-observers: minor performance improvement
  * osc: seekbar hover/drag: display target chapter at the title
  * manpage: add article in fuzzy explanation
  * player: remove unnecessary check
  * player: fix segfault
  * osc: ensure tick after any mouse-event
  * osc: don't initialize while mouse-down over an element
  * osc: update chapter marker positions when duration changes
* Mon Jun 14 2021 ismail@i10z.com
- Update to version 0.33.1+git.20210613T225337.bc9d556f3a:
  * js: add mp.utils.append_file
  * vo_gpu: vulkan: displayvk: Fix handling of unconnected planes
  * vo_gpu: vulkan: implement a VkDisplayKHR backed context
  * vo_gpu: vulkan: provide a helper to access device name option
  * vo_rpi: fix argument name
  * github/issue_template: irc -> IRC
  * {ci,docs,README}: update IRC references to new network
  * docs: fix leftover reference to the now defunct --video-sync-adrop-size option
  * ytdl_hook: improve handling of json parsing errors
* Sat May 29 2021 ismail@i10z.com
- Update to version 0.33.1+git.20210528T161101.d7f3d1fff7:
  * wayland: refactor dispatching events
  * manpage: mention cover-art-auto
  * README: fix link to feature-request issues
  * player: load cover art with the media filename
  * win32: support the property 'focused'
  * osc: re-initialize when chapter list changes
  * recorder: fix codec_tag / codec_id confusion
  * recorder: clear codec_tag if no target format support
  * af_scaletempo2: use gcc vectors to speed up inner loop
  * vo_gpu: replace --icc-contrast by --icc-force-contrast
  * wayland: shuffle around the render loop again
  * wayland: send VO_EVENT_DPI on output event as well
  * command: add a missing comma to MP_EVENT_WIN_STATE
  * vo_gpu: fix extreme clipping with --gamut-clipping for HDR outputs
  * wayland: simplify render loop
  * player/command: add secondary-sub-text property
  * sub/osd: hide secondary subtitles if secondary-sub-visibility is false
  * vo_gpu: hwdec_vaapi: silence errors while probing
  * stream_lavf: remove uninitialized http_like array
  * osxbundle: fix slow and wasteful memory allocation
  * stream_file: disable read ahead for remote files on macOS
  * build: move mingw jobs to Github actions
  * build: move website rebuild into Linux/clang travis job
* Fri May 14 2021 ismail@i10z.com
- Update to version 0.33.1+git.20210511T222233.ded36a4470:
  * options: add some entries to --display-tags defaults
  * ytdl_hook: expose some JSON fields as tags
  * edl: add a way to add tags
  * zsh completion: perform globbing on binary path
  * vo_gpu: fix trivial memory leak
  * Revert "vo_gpu: revert 8a09299 and conditionally clear framebuffer again"
  * vf_sub: restore OSD if removed
  * options: extend --replaygain-preamp range
  * audio: fix replaygain being completely broken
  * Revert "audio: set audio chain ao on reinit"
  * mac: add support for display-width/display-height property
  * command: add display-width/display-height property
  * DOCS/input.rst: clarify --no-input-default-keybindings docs
  * filter_kernels: fix quadric window
  * DOCS/lua.rst: fix docs for utils.file_info
  * build: address AVCodec, AVInputFormat, AVOutputFormat const warnings
  * scripting (lua/js): utils.getpid: make wrapper of pid property
  * command: new property: pid (process id)
  * DOCS: clarify how client/script names work
  * command: osd-dimensions: return ints and doc fixes
  * audio: add two minor log messages
  * ao/pulse: fix incorrect state reported after reset
  * osc: reset margins when using boxvideo with showfullscreen/showwindowed
  * wayland: ignore toplevel listener if geometry is 0
  * osc: display immediately when visibility changes from never to always
  * mac: fix window geometry calculation on secondary screens
  * stream_file: add new identifier for macOS FUSE filesystems
  * DOCS: mpv.rst: minor escaping clarifications
  * win32: fit_window_on_screen: simplify, add comments
  * win32: fit_window_on_screen: centralize logic (no-op)
  * win32: fit_window_on_screen: ensure top edge is inside
  * options: win32: ignore and deprecate --fit-border
  * demux_lavf: fix minor memory leaks
  * vo_gpu: greatly increase maximum shader cache size
  * wayland: workaround hidden state detection badness
  * audio: set audio chain ao on reinit
  * wayland: update geometry + cursor on output event
* Tue Apr 13 2021 idoenmez+factory@suse.de
- Update to version 0.33.1+git.20210412T140928.74f5d4940e:
  * wayland: support the display-hidpi-scale property
  * demux: undeprecate --cache-secs
  * audio/aframe: reuse data buffer if less than 8 channels
  * stream: turn stream_info.open2's args argument const
  * stream_slice: fix use-after-free if inner stream fails to open
  * player/scripting: fix use-after-free when loading script folders
  * stream_mf: set correct stream origin
  * demux_mf: improve format string processing
  * manpage: fix a typo in the --aid option note
  * vo_gpu: adjust interpolation_threshold's default
  * options: Add validation macro for int type
  * demux: Move demuxer help to new standard mechanism
  * options: Make validation and help possible for all option types
* Tue Mar 23 2021 idonmez@suse.com
- Update to version 0.33.0+git.20210321T171820.6265724f33:
  * vo_gpu: placebo: keep track of texture sample mode
  * stats.lua: include a filter's @label when displaying filters on page 1
  * ao_oss: add this audio output again
  * audio: prevent uninit_audio_out during encoding
  * stream_lavf: add support for Gopher over TLS.
  * ao/pulse: signal the mainloop when ops are done
  * player/command: add albumart argument to video-add
  * player/{core,loadfile}: make cover art loading more explicit
  * ao/pulse: wait for command completion when setting volume or mute
  * ytdl_hook: fix crash on missing track bitrate
  * umpv: Use generator expression for files
  * wayland: no mouse dragging in fullscreen/maximized
  * manpage: mention rotate limitations with hwdec
  * vd_lavc: wrap use of deprecated AVCodecContext.thread_safe_callbacks in #if
  * manpage: video-rotate supports arbitrary steps
  * mac: fix traditional fullscreen on macOS 11
  * mac: remove an unused variable
* Fri Mar 12 2021 Илья Индиго <ilya@ilya.pp.ua>
- Added JS scripting support (mujs) for Tumbleweed and Leap > 15.3.
* Thu Feb 25 2021 idonmez@suse.com
- Update to version 0.33.0+git.20210223T124404.09d7c75bfe:
  * vo_gpu: libplacebo: require v2.72.0
  * appveyor: Use MSYS2's spirv-cross package instead of building it
  * appveyor: use latest build image for fixed MSYS2 installation
  * msg: fix really-quiet option to only affect terminal output
  * mac: add ability to toggle visibility on all workspaces from menubar
  * command: add label for on-all-workspaces command
  * mac: support --on-all-workspaces option
  * vo_gpu: don't abort() if plane tex creation fails
  * filters/auto_filters: switch from scaletempo to scaletempo2
  * af_scaletempo2: fix crash for speed >= 16
  * travis: fix macOS VMs with older homebrew versions
  * mac: only update touch bar items when necessary
  * mac: use custom touch bar item and slider instead of a touch bar slider
  * vo_gpu: vaapi: export plane pitch properly
  * DOCS: fix cplugins information in libmpv.rst.
  * demuxer/demux_mf: add support for more image codecs
  * man: update deband-threshold default
  * vo_gpu: lower default deband threshold
  * vo_wlshm: support big endian systems
  * README: update libass dependency harfbuzz as non-optional
  * manpage: fix PDF build
  * docs: Fix an old style parameter reference
  * umpv: remove unused imports
  * stream_lavf: support rtsps
  * player: make resetting of track selection to "auto" work
  * mac: fix dangling pointers
  * mac: drop build support for swift versions earlier than version 4.1
  * mac: fix usage of temporary pointers
  * manpage: document off-by-one loop-file behavior
* Sun Jan  3 2021 idonmez@suse.com
- Update to version 0.33.0+git.20210103T120530.1251f7bbf9:
  * manpage: rename OS X references to macOS
  * vo_gpu: don't segfault if 3DLUT texture fails uploading
  * input.conf syntax: support custom quotes !XstringX!
  * input.rst: fix typo commands -> arguments
  * csputils: add mappings for DCI-P3 (ST.431-2) and P3-D65 (ST.432-1)
  * vd_lavc: add VP8 to the default allowed hwdec codec list
  * vo_gpu: cast bvecN to vecN for mix() on older GLSL
  * bootstrap: log caught URLError
  * Revert "build: recognize Lua 5.1 on Arch Linux"
  * build: fail configure if --lua is specified and Lua isn't found
* Mon Dec 21 2020 idonmez@suse.com
- Update to version 0.33.0+git.20201220T105748.1ba5dc84ca:
  * wayland: support multiple modifiers
  * mac: fix type mismatch Int instead of Int32
  * mac: use visible frame rectangle for window geometry calculation
  * mac: fix a window positioning bug when exiting fullscreen
  * appveyor: use MSYS2 shaderc package
  * vo_wlshm: support presentation time
  * wayland: unify frame/presentation callback code
  * x11: update geometry/autofit opts on runtime
  * wayland: update geometry/autofit opts on runtime
  * console: use wl-paste on Wayland
  * wayland: remove unused function declaration
  * auto_profiles: fix compile_cond on lua 5.1
  * build: recognize Lua 5.1 on Arch Linux
  * manpage: document background transparency
  * manpage: clarify that you can prefetch m3u8 urls
  * wayland: handle multiple outputs more correctly
  * vo_gpu: revert 8a09299 and conditionally clear framebuffer again
  * mac: support screen-name and fs-screen-name opts
  * wayland: support fs-screen-name option
  * x11: support screen-name and fs-screen-name opts
  * player: add --screen-name and --fs-screen-name
  * manpage: clarify profile-cond requires underscores
  * build: restore support for non-pkgconfig zlib
  * build: use pkg-config for zlib
  * vo_gpu: placebo: update for upstream API changes
  * vo_sixel: don't divide by zero on small terminal
  * vo_sixel: re-fit image on terminal resize
  * vo_sixel: refactor of resize, reconfig (no-op)
  * vo_sixel: Update description string of vo driver
  * csputils: add MP_CHROMA_TOPLEFT
* Mon Nov 30 2020 idonmez@suse.com
- Update to version 0.33.0+git.20201129T160245.f16c6472a1:
  * travis: use newer 10.15 VM with newer xcode
  * travis: fix macOS 10.13 build
  * vo_sixel: don't leak the frame reference
  * vo_tct: don't leak the frame reference
  * vo_tct: remove unused variable
  * player: allow vo to be switched at runtime
  * demux: add function to refresh a track without (de-)selecting it
  * vo_sixel: use draw_frame instead of draw_image
  * vo_sixel: skip testdither init in fixed palette
  * vo_sixel: Update libsixel constant values
  * matroska.py: remove python2 support
  * bootstrap.py: remove all python2 support
  * vo_sixel: change default dither to "auto"
  * vo_sixel: fix the image corruption with mlterm
  * vo_sixel: support --vo-sixel-exit-clear[=yes]
  * terminal: process input when foregrounded
* Sun Nov 22 2020 idonmez@suse.com
- Update to version 0.33.0+git.20201122T184820.fa7afc3e19:
  * Update VERSION
  * Release 0.33.0
  * file2string: remove question mark from safe chars
  * Revert "options: disable vsfilter blur compat by default"
  * build: always run waf with python3
  * build: fix macOS arm builds
  * vo_sixel: draw osd on the output frame
  * vo_sixel: return -1 instead of SIXELSTATUS on failure
  * vo_sixel: set --vo-sixel-fixedpalette=yes by default
  * vo_sixel: Add aspect ratio based output centering
  * vo_sixel: rename all user options with opt_ prefix
  * vo_sixel: set output resolution based on terminal_get_size2
  * osdep/terminal: Add function to get terminal pixel dimensions
  * doc: split BNF definitions of <command> and <argument> in separate lines
  * manpage: document improved --playlist security
* Tue Nov 17 2020 idonmez@suse.com
- Update to version 0.32.0+git.20201116T202958.24d6961833:
  * command: mouse: generate MOUSE_{ENTER,LEAVE} if required
  * docs/input.rst: document the mouse-pos property
  * command: mouse-pos property: add field "hover"
  * lua/js: mp.get_mouse_pos: use the mouse-pos property
  * command: new property: mouse-pos
  * command: add internal INPUT_PROCESSED event
  * path: do not use old_home for win32 exe dir
  * js: report scripts CPU/memory usage statistics
  * ci: fix mingw build by adding harfbuzz
  * command: make subtitle time properties observable
  * manpage: properties fixes
  * manpage: document the property-change event
  * manpage: document video-frame-info sub-properties
  * manpage: remove redundant "Return(s) "
  * manpage: document demuxer-cache-state better
  * manpage: be consistent with booleans
  * vo_sixel: Add fallback terminal width and height
  * vo_sixel: Add checks to prevent null pointer dereferencing.
  * ao_alsa: handle -EPIPE XRUNs from snd_pcm_status
  * ao_alsa: always initialize state if passed
  * wayland: fix buffer overrun in get_mods
  * wayland: check for modifier keys on pointer events
  * Revert "wayland: conditionally commit surface on resize"
  * DOCS: correct interface-changes.rst
  * mac: make focus property observable
  * video/out/vo_sixel.c: Implement sixel as a output device
  * manpage: document av1 addition to --hwdec-codecs default setting
  * vd_lavc: add AV1 to the default allowed hwdec codec list
  * player: fix external cover file prioritization
  * input.conf: add default keybindings for sub-scale
  * console: let type set the cursor position
  * ytdl_hook: if ytdl not found in config dirs, use ytdl_path as is
  * ytdl_hook: support alternative youtube-dl path
  * player: reorder list of external cover files for optimal results
  * build: disable wayland if linux/input-event-codes.h isn’t available
  * wayland: use more specific input codes header
  * demux_lavf: initialize ReplayGain data
  * command: add delete-watch-later-config
  * vo_gpu: improve gamut warning bounds checks
  * wayland: don't use presentation time if ust is 0
* Mon Oct 19 2020 idonmez@suse.com
- Update to version 0.32.0+git.20201016T174805.cbbdb3fae4:
  * stats: display hw pixel format too
  * command: expose underlying pixfmt for hwdec
  * manpage: Document behaviour of *nix configuration directories
  * build: bump waf to 2.0.20
  * stream_lavf: enable SRT protocol support through FFmpeg
  * vo_gpu: fix segfault when updating render opts
  * vo_gpu: EGL: hack for alpha on different platforms
  * wayland: update opaque region on runtime
  * vo_gpu: update render options on runtime
  * wayland: be less strict about when to render
  * docs: fix simple typo, unminimze -> unminimize
  * DOCS: fix typo on sub-filter-regex-enable
  * manpage: reference standard for configuration file location
* Fri Oct  9 2020 idonmez@suse.com
- Update to version 0.32.0+git.20201008T111710.16b44d93f7:
  * Revert "demux: add a POS"
  * player: fix another nightmarish corner case
  * demux: add a POS
  * Revert "wayland: add wayland-display-socket option"
  * wayland: add wayland-display-socket option
  * screenshot: add --screenshot-sw option
* Sat Oct  3 2020 idonmez@suse.com
- Update to version 0.32.0+git.20201001T111222.34b8adc456:
  * wayland: set an opaque region
  * options: fix --cover-art-file typo
  * player: cosmetically change around some code
  * player: add automatic loading of external cover art files
  * player: let frontend decide whether to use cover-art mode
  * ci: fix spirv-cross build in mingw scripts
  * mac: add support for the focused property
  * mac: add an option to prevent focusing of the window on open
* Tue Sep 22 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200922T130339.c535dfed66:
  * travis: fix macOS 10.12 legacy build
  * wayland: only render if we have frame callback
  * player: add pause state to playback start message
  * terminal: fix segfault when backgrounding
  * f_decoder_wrapper: make log prefix less verbose
  * audio: take paused state into account in ao_start()
  * audio: move start() calls outside of lock
  * mac: add an option to change the App activation policy
  * mac: add ontop window level for desktop
  * options: simplify --android-surface-size handling
  * build: disable GLX
  * manpage: fix console keybindings punctuation
  * msg: make --msg-time show time in seconds
  * build: sort dependencies (to make build deterministic)
  * command, demux: make drop-buffers reset state even harder
  * terminal: attempt to handle the ESC key
  * client API: update alignment requirements for software rendering
  * sws_utils: work around libswscale corrupting memory yet again
  * manpage: refer to --sub-color for colors
  * manpage: mark file-local-options as writable
  * stream_slice: interpret `end` as offset if it starts with '+'
* Mon Sep 14 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200912T130313.49f5c9b482:
  * command: add property track-list/N/main-selection
  * player: fix inconsistent AO pause state in certain situations
  * player: some minor code golf
  * vo_vdpau: remove an unused variable
  * player: clamp relative seek base time to nominal duration
  * manpage: "fix" some formatting
  * terminal-unix: attempt to support more CTRL
  * vo_vdpau: remove deprecated/inactive --vo-vdpau-deint option
  * command: add read-only focused property
  * manpage: fix typo
* Sun Sep  6 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200904T003159.f57b90b069:
  * options: fix a flags field
  * ao_alsa: make partial writes an error message
  * audio: fix stream-silence with push AOs (somewhat)
  * encode: propagate errors to exit status properly
  * ao_lavc: slightly simplify filter use
  * client API: inactivate the opengl_cb API
  * encode: disable unsupported media types automatically
  * encode: remove early EOF failure handling
  * audio: slightly simplify audio_start_ao()
  * audio: reduce excessive logging of delayed audio start
  * ao_alsa: log more information on short writes
  * audio: do not show audio draining message when it does not make sense
  * audio: do not wake up player when waiting for audio state and paused
  * audio: fix AVFrame allocation (crash with opus encoding)
  * DOCS/interface-changes: remove encoding mode deprecation entry
  * player/playloop.c: reorder included headers per contribute.md
  * ao_openal: restore working condition with new push API
  * ao: remove unused field
  * audio: fix inefficient behavior with ao_alsa, remove period_size field
  * encode: undeprecate
  * ring: remove this
  * audio_buffer: remove this
  * audio: refactor how data is passed to AO
  * DOCS: fix minor issue on the --video-latency-hacks explanation
  * Update compile-windows.md
  * manpage: reorder sentence
  * f_async_queue: add various helper functions
  * f_async_queue: don't count EOF frames as samples
  * f_async_queue: change reset behavior
  * filter: add filter priority thing
  * manpage: slightly improve property list note
  * sd_ass: replace deprecated ASS_OVERRIDE_BIT_FONT_SIZE
  * osd_libass: don't use deprecated ass_set_aspect_ratio
* Fri Aug 28 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200827T184057.fc6c209cbd:
  * f_demux_in: log EOF "recovery"
  * f_decoder_wrapper: pass through EOF after EOF
  * player: fix video paused condition on VO creation
  * filter: add a helper
  * audio: clarify set_pause() documentation
  * audio: adjust frame clipping for spdif formats
  * audio: remove unused ring.h includes
  * player: fix swapped debug output
  * vo_gpu: EGL: fix transparency on X11/EGL/Mesa
  * vo_gpu: EGL: slightly better debug logging of EGL configs
  * ao/pulse: create the stream corked
  * wayland: always update sbc for presentation time
  * Revert "demux_lavf: always give libavformat the filename when probing"
  * audio: remove delay debug logging
  * wayland: simplify presentation time
  * demux_mf: actually report errors
  * player: do not loop if there's nothing to loop
  * options: do not accept ":" as separator anymore in key/value lists
  * cocoa-cb: force layer update on resize
  * mac: add icc profile and ambient light sensor support
  * mac: use config cache und wakeup for mac option runtime changes
  * mac: make ontop level runtime changeable
  * mac: properly guard and unwrap an optional value
  * cocoa-cb: generalisation of backend independent parts
* Fri Aug 21 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200820T203717.b16a6cb6c6:
  * client API: note about libswscale corrupting memory
  * wayland: conditionally commit surface on resize
  * player: add --subs-with-matching-audio option
  * wayland: refactor geometry/window handling
  * stream: Implement slice:// for reading slices of streams
  * wayland: reset geometry on reconfig if fullscreen
  * wayland: soften GNOME warning
* Mon Aug 17 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200816T162900.486516f723:
  * See https://github.com/mpv-player/mpv/compare/fb55ee99e3..486516f723
    for the complete changelog.
* Tue Aug  4 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200802T170651.fb55ee99e3:
  * See https://github.com/mpv-player/mpv/compare/8fbc4b1737..fb55ee99e3
    for the complete changelog.
* Mon Jul  6 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200701T004440.8fbc4b1737:
  * ci: add d3d11 to mingw build
  * vo_gpu: vulkan: add ability to disable events
  * player: warn if both proper and compat. config directories exist
  * path: do not use old_home for win32 exe dir
  * path: switch back to using non-XDG config dir by default
  * vo_gpu: fix typo in struct name
  * manpage: --demuxer-seekable-cache is useless
  * ci: replace mingw build scripts
  * vo_gpu: use highp float if available for GLES
  * vo_gpu: add better gamut clipping option
  * vo_gpu: fix scaler/window validation to allow unsetting
  * vo_x11: partially restore operation on bad endian systems
  * video: some concessions to big endian hosts
  * test: update to new ffmpeg pixfmts
  * video: alias IMGFMT_RGB30 to AV_PIX_FMT_X2RGB10
  * repack: handle endian in a more general way
  * img_format: fight ffmpeg pixdesc some more
  * audio: don't lock ao_control for pull mode drivers
  * vo_gpu: placebo: add fallback code for stride mismatch
  * vo_gpu: add BT.2390 tone-mapping
  * vo_gpu: reinterpret SDR white levels based on ITU-R BT.2408
* Sun Jun 14 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200610T171643.c7fe4ae73a:
  * vo_gpu: move coherent specifier to the correct location
  * player: make unpausing directly after seek work with --keep-open (again)
* Wed Jun 10 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200609T164905.d5de79d10f:
  * See https://github.com/mpv-player/mpv/compare/b83bdd1d17..d5de79d10f
    for the complete changelog.
* Mon May 25 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200525T015437.b83bdd1d17:
  * See https://github.com/mpv-player/mpv/compare/82ded968aa..b83bdd1d17
    for the complete changelog.
* Mon May 18 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200518T015720.82ded968aa:
  * See https://github.com/mpv-player/mpv/compare/cae2ffb6eb..82ded968aa
    for the complete changelog.
* Sat May  2 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200501T204851.cae2ffb6eb:
  * See https://github.com/mpv-player/mpv/compare/027ae815ec..cae2ffb6eb
    for the complete changelog.
* Tue Apr 28 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200426T233854.027ae815ec:
  * See https://github.com/mpv-player/mpv/compare/a09c7691d7..027ae815ec
    for the complete changelog.
* Wed Apr 22 2020 Ismail Dönmez <idonmez@suse.com>
- Add BR on pkgconfig(ffnvcodec) to enable CUDA support
* Mon Apr 20 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200418T001652.a09c7691d7:
  * See https://github.com/mpv-player/mpv/compare/5824ac7d36..a09c7691d7
    for the complete changelog.
* Thu Apr  2 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200402T120653.5824ac7d36:
  * See https://github.com/mpv-player/mpv/compare/28ea1ed296..5824ac7d36
    for the complete changelog.
* Sat Mar  7 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200307T135520.28ea1ed296:
  * See https://github.com/mpv-player/mpv/compare/e7bab0025f..28ea1ed296
    for the complete changelog.
- Remove smbclient BR, samba support is now provided via ffmpeg
* Sun Mar  1 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200301T004003.e7bab0025f:
  * See https://github.com/mpv-player/mpv/compare/ee6ad403a7..e7bab0025f
    for the complete changelog.
* Sat Feb 22 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200222T142106.ee6ad403a7:
  * See https://github.com/mpv-player/mpv/compare/36ca0e0030..ee6ad403a7
    for the complete changelog.
* Mon Feb 17 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200217T003119.36ca0e0030:
  * See https://github.com/mpv-player/mpv/compare/5bf433b16f..36ca0e0030
    for the complete changelog.
* Thu Feb 13 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200213T013258.5bf433b16f:
  * See https://github.com/mpv-player/mpv/compare/6799f8e0e9..5bf433b16f
    for the complete changelog.
* Sun Feb  9 2020 idonmez@suse.com
- Update to version 0.32.0+git.20200208T095058.6799f8e0e9:
  * See https://github.com/mpv-player/mpv/compare/cbee577d0a..6799f8e0e9
    for the complete changelog.
* Tue Feb  4 2020 hpj@urpla.net
- Update to version 0.32.0+git.20200203T191344.cbee577d0a:
  * See https://github.com/mpv-player/mpv/compare/f304a79935..cbee577d0a
    for the complete changelog.
- switch time tag in version to (much more comprehensible) iso format
* Sun Feb  2 2020 idonmez@suse.com
- Update to version 0.32.0+git.1580606151.f304a79935:
  * See https://github.com/mpv-player/mpv/compare/cbfcd3e703..f304a79935
    for the complete changelog.
* Mon Jan 27 2020 idonmez@suse.com
- Update to version 0.32.0+git.1580083289.cbfcd3e703:
  * See https://github.com/mpv-player/mpv/compare/01de2a9bd5..cbfcd3e703
    for the complete changelog.
  * mpv now generates its own bash-completion file
* Sat Jan 18 2020 Martin Herkt <9+suse@cirno.systems>
- Run spec-cleaner
- Conflict with broken versions of mpv-plugin-mpris
* Sat Jan 11 2020 Luigi Baldoni <aloisio@gmx.com>
- Update mpv-bash-completion to 3.3.18
  * Fix crash with mpv > 0.31.0
* Sat Dec 28 2019 idonmez@suse.com
- Update to version 0.31.0+git.1577540072.01de2a9bd5:
  * See https://github.com/mpv-player/mpv/compare/1caa653f2d..01de2a9bd5
    for the complete changelog.
* Fri Dec 27 2019 idonmez@suse.com
- Update to version 0.30.0+git.1577220684.1caa653f2d:
  * See https://github.com/mpv-player/mpv/compare/0bf0efd6d3..1caa653f2d
    for the complete changelog.
* Tue Dec 17 2019 idonmez@suse.com
- Update to version 0.30.0+git.1576544262.0bf0efd6d3:
  * See https://github.com/mpv-player/mpv/compare/cb2d7c1534..0bf0efd6d3
    for the complete changelog.
- Update mpv-make-ffmpeg-version-check-non-fatal.patch for a simpler
  logic.
* Sat Nov  9 2019 idonmez@suse.com
- Update to version 0.30.0+git.1573301895.cb2d7c1534:
  * See https://github.com/mpv-player/mpv/compare/a908101258..cb2d7c1534
    for the complete changelog.
* Sat Oct 26 2019 idonmez@suse.com
- Update to version 0.30.0+git.1572040975.a908101258:
  * See https://github.com/mpv-player/mpv/compare/acba87e53f..a908101258
    for the complete changelog.
- Enable zimg support: Add BR on pkgconfig(zimg), add --enable-zimg
* Sat Oct 19 2019 idonmez@suse.com
- Update to version 0.30.0+git.1571393471.acba87e53f:
  * See https://github.com/mpv-player/mpv/compare/a85fa2d2de..acba87e53f
    for the complete changelog.
* Sat Oct 12 2019 idonmez@suse.com
- Update to version 0.30.0+git.1570822084.a85fa2d2de:
  * See https://github.com/mpv-player/mpv/compare/c833c095d7...a85fa2d2de
    for the complete changelog.
  * Fixes rendering glitches on Wayland
* Sun Oct  6 2019 idonmez@suse.com
- Update to version 0.30.0+git.1570361388.6d0f0546ee:
  * See https://github.com/mpv-player/mpv/compare/c833c095d7...6d0f0546ee
* Sun Sep 29 2019 idonmez@suse.com
- Update to version 0.30.0+git.1569760020.c833c095d7:
  * See https://github.com/mpv-player/mpv/compare/b6def652a4...c833c095d7
    for the complete changelog.
- Refresh mpv-make-ffmpeg-version-check-non-fatal.patch
- Remove --enable-zsh-comp option, zsh completion is now always enabled
* Mon Sep 23 2019 idonmez@suse.com
- Update to version 0.30.0+git.1569184750.b6def652a4:
  * See https://github.com/mpv-player/mpv/compare/0abe34ed21...b6def652a4
    for the complete changelog.
* Tue Sep 17 2019 idonmez@suse.com
- Update to version 0.30.0+git.1568566852.0abe34ed21:
  * vo_gpu: x11: remove special vdpau probing, use EGL by default
  * vf_vavpp: disable this filter
  * vo_gpu: correctly normalize src.sig_peak
  * image_writer: add webp-compression option
  * image_writer: add WebP support (lossy or lossless)
  * image_writer: move convert_image() to player/screenshot.c
  * DOCS: remove references to --video-stereo-mode
  * README: remove old googlegroups mailing list address
  * manpage: minor fixes to VO manpage
  * vo: add warning message to vo_vaapi and vo_vdpau
  * vo_d3d11/context: fix crash due to ctx->ra is null pointer access 'ctx->ra' is null pointer when d3d11 init failed before call 'ra_d3d11_create' in 'd3d11_init'.
  * vo_d3d11/hwdec_dxva2dxgi: fix memory leak that 'ctx11' be not release 'ctx11' be not release when d3d11 hwdec be uninit with 'mapper_uninit' method.
  * stream_smb: remove unnecessary short write logic
  * stream_file: remove unnecessary short write logic
  * stream: handle short writes
  * ci: remove now unuspported libdvdread
  * demux, stream: remove old rar support in favor of libarchive
  * command, demux: remove program property
  * stream: remove some more optical disc leftovers
  * Remove classic Linux analog TV support, and DVB runtime controls
  * stream: remove BD/DVD/CDDA sector size alignment
  * Remove optical disc fancification layers
  * stream_dvdnav: merge stream_dvd_common
  * Remove libdvdread support in favor of libdvdnav
  * stream_file: avoid redundant free
  * js: expose mpv_abort_async_command() (match dbe831bd)
  * js: reimplement subprocess_detached using the run command (match 7f91e268)
  * js: reimplement subprocess using the subprocess command (match 548ef078)
  * js: expose async commands (match 159379980e)
  * js: correctness: use integer range checks
  * audio: block ao buffer for keep-open
  * vo_gpu: x11egl: support Mesa OML sync extension
  * vo_gpu: glx: move OML sync code to an independent file
  * vo/gpu: fix check on src/dst peak mismatch
* Mon Sep  2 2019 idonmez@suse.com
- Update to version 0.30.0+git.1567376743.6d90517275:
  * external_files: add .lrc subtitle extension
  * demux: ignore forced demuxer type for directories
  * stream_dvb: Increase timeout of streaming read.
  * stream_dvb: Adapt to VDR channel config format.
  * osc: improve look of seekranges
  * cocoa-cb: remove an unused variable
  * ao_opensles: fix delayed audio
  * travis: rework scripts to re-enable macOS
  * vo/gpu: vulkan: Pass the device name option through to libplacebo
* Thu Aug 22 2019 Ismail Dönmez <idonmez@suse.com>
- Reintroduce _mpv_ver since subpackages have different versions
  and need to depend on _mpv_ver when appropriate.
* Tue Aug 20 2019 Ismail Dönmez <idonmez@suse.com>
- Disable set_version so that the bash-completion subpackage
  gets the correct version.
* Tue Aug 20 2019 idonmez@suse.com
- Update to version 0.30.0+git.1566288741.80552ab28e:
  * vo_gpu: d3d11: fix storage lifetime of compound literals
  * encode: set sample_aspect_ratio on AVStream struct
  * vo_gpu: fix taking screenshots of rotated videos
  * vo_gpu: hwdec_vaapi: Synchronise after exporting VA surface
  * DOCS/compile-windows: remove angleproject-git from deps
  * TOOLS/travis-rebuild-website: update condition after docker transition
  * cocoa-cb: migrate to swift 5 with swift 4 fallback
  * cocoa-cb: fix optional cases on macOS 10.12
  * build: fix build with older command line tools
  * build: make macOS SDK path and version configurable via env vars
* Thu Nov 22 2018 Tomáš Chvátal <tchvatal@suse.com>
- Add vulkan dependency per bsc#1115120
* Fri Oct 26 2018 jslaby@suse.com
- enable tv
* Tue Oct  2 2018 Martin Herkt <9+suse@cirno.systems>
- Update to version 0.29.1
  Fixes and minor enhancements:
  * af_rubberband: Fix for A-V drift on seeking.
  * ao_alsa: Fixes to remove spam during pausing and end-of-file.
  * ao_jack: Fix for mpv attempting to connect to non-standard devices such as MIDI.
  * ao_openal: Drop support for Apple's bundled OpenAL due to lack of features to successfully build.
  * ao_pulse: Fix for audio buffer length calculation.
  * demux_lavf: Fix EDL playback of certain DASH streams.
  * demux_lavf: Mark v4l streams as not seekable.
  * demux_raw: Fix for gapless playback from raw audio input.
  * drm_atomic: Fix to enable video output with devices without a video overlay plane.
  * encode: Fix for crashes in case of failure to write to output.
  * encode: Fix for encoding when utilizing lavfi-complex.
  * Fix to strip HDR peak metadata if attached to SDR video (#6111)
  * manpage: Misc fixups.
  * stream_{smb,file}: Fix for partial writes to buffers.
  * stream_libarchive: Fix hang when an out-of-bound seek happens.
  * stream_smb: Fix for crashes due to libsmbclient and threading (#5936).
  * vo_gpu: Fix for corruption when multiple compute shaders override each others' block sizes (#6083).
  * ytdl_hook: Always load "ytdl://" URLs with ytdl_hook first.
  * ytdl_hook: Fix audio streams not being picked up for some sites.
* Sun Jul 22 2018 aloisio@gmx.com
- Update to version 0.29.0
  * This release requires FFmpeg 4.0 or newer.
  Added features:
  * ao/openal: Add better sample format and channel layout
    selection
  * ao/openal: Add support for direct channels output
  * cocoa-cb: initial implementation via opengl-cb API
  * context_drm_egl: Introduce 30bpp support (requires Mesa
    18.0.0_rc4 or later)
  * osx: add some more menu bar items as suggested by Apples's
    HIG
  * vo_gpu: make screenshots use the GL renderer (#5498, #5240)
  * x11: support Shift+TAB as an input key bind (#5849)
  * ytdl_hook: support native dash demuxer, if present
  Changed features
  * ao_alsa, ao_pulse: reduce requested buffer size
  * audio: change format negotiation, remove channel remix
    fudging
  * client API: deprecate opengl-cb API and introduce a
    replacement API
  * demux: lower demuxer cache default sizes from 400MB/400MB to
    50MB/150MB
  * osx: always deactivate the early opengl flush on macOS
  * scripting: change when/how player waits for scripts being
    loaded
  * vo_gpu: various improvements to HDR peak detection
  * vo_gpu: various improvements to HDR tone mapping
  * wayland_common: update to stable xdg-shell
  * ytdl_hook: parse youtube playlist urls to set start index if
    `--ytdl-raw-option=yes-playlist=` is specified
  Deprecated features:
  * af_lavrresample: deprecate this filter
  Removed features:
  * build: drop support for SDL1 (only applied to ao_sdl)
  Added options and commands:
  * add a number of --audio-resample-* options, which should
    from now on be used instead of --af-defaults=lavrresample:
  * ao/openal: --openal-direct-channels
  * command: add --osd-on-seek option defaulting to bar
  * command: add a change-list command (#5435)
  * options: add --http-proxy
  * options: add a builtin low-latency profile
  * vaapi: add option to select a non-default device path with
  - -vaapi-device (#4320)
  * video: add option to reduce latency by 1 or 2 frames
  * vo_gpu: introduce --target-peak (#5521)
  Changed options and commands:
  * command: change cycle-value command behavior (#5772)
  * config: replace config dir lua-settings/ with dir
    script-opts/
  * options: --lavfi-complex now requires uniquely named filter
    pads.
  * options: --ytdl is now always enabled, even for libmpv
  * options: make --deinterlace=yes always deinterlace (#5219)
  * options: slightly improve filter help output for lavfi bridge
  * vo: rename --vo=opengl-cb to --vo=libmpv
  Deprecated options and commands:
  * encoding: deprecate a bunch of obscure options (--ovoffset,
  - -oaoffset, --ovfirst, --oafirst)
  * options: deprecate --vf-defaults and --af-defaults
  * osx: --gpu-context=cocoa with --gpu-api=opengl is now
    deprecated in favour of --vo=libmpv
  Removed options and commands:
  * command: remove an old compatibility hack that allowed CLI
    aliases to be set as property, deprecated in 0.26.0
  * input: remove legacy command handling for MPlayer commands
    that were deprecated in 2013
  * options: drop --opensles-sample-rate, as --audio-samplerate
    should be used if desired
  * options: drop deprecated --videotoolbox-format, --ff-aid,
  - -ff-vid, --ff-sid, --ad-spdif-dtshd, --softvol options
  * options: remove --video-stereo-mode
  * options: remove deprecated ao/vo auto profiles
  * options: remove the following encoding options: --ocopyts
    (now the default, old timestamp handling is gone), --oneverdrop
    (now default), --oharddup (you need to use --vf=fps=VALUE),
  - -ofps, --oautofps, --omaxfps
  Fixes and minor enhancements:
  * HIDRemote: fix volume buttons on macOS 10.13 (#5721)
  * TOOLS/autoload: Fix broken "disabled" option
  * TOOLS/autoload: be more robust with slow directory listings
    (#5618)
  * ao_sdl: fix default buffer size
  * build: add static libraries to libmpv.pc
  * build: bump waf to 2.0.9 (fixes Python 3.7 compatibility)
  * build: manually add standard library search paths for
    linking (#5791)
  * common: round all integer times to milliseconds
  * demux, player: fix playback of sparse video streams (w/
    still images)
  * demux: support for some kinds of timed metadata (e.g. ICY)
  * demux_mkv: add V_AV1 identifier for AV1
  * demux_mkv: support Meridian Lossless Packing in Matroska
    (#5923)
  * display additional metadata tags during video playback
  * drm_atomic: Fix memory leaks in drm_atomic_create
  * enable cache for FUSE filesystems on OpenBSD and FreeBSD
  * gpu: prefer 16bit floating point FBO formats to 16bit
    integer ones
  * hwdec_vaegl: Fix VAAPI EGL interop used with gpu-context=drm
  * input.conf: use exact value for [ binding, which does the
    inverse of ]
  * input: add a keybinding to toggle hardware decoding
  * input: minor additions to default key bindings (#973)
  * osc: fix accidentally skipping files when seeking with slider
  * player: fix strange behavior on edition switching
  * player: fix track autoselection of external files yet again
  * terminal-unix: stop trying to read when terminal disappears
    (#5842)
  * video: actually wait for last frame being rendered on EOF
  * video: fix --video-rotate in some cases
  * video: fix crash with vdpau when reinitializing rendering
    (#5447)
  * vo_gpu: fix anamorphic screenshots (#5619)
  * vo_vdpau: fix resizing and rotation problems
- Refreshed mpv-make-ffmpeg-version-check-non-fatal.patch
- Bumped waf to 2.0.9
- Enable wayland only for Tumbleweed due to version constraints
* Sat Jun  2 2018 aloisio@gmx.com
- Updated mpv-bash-completion to 3.3.17
  * Added the ability to filter media file completion suggestions
    by multimedia file extensions (see README).
  Bug fixes:
  * --show-profile argument completion now suggests the list of
    existing profile names.
* Mon May 21 2018 9+suse@cirno.systems
- Drop libguess from BuildRequires (unused)
- Actually use optflags for build
* Sat Apr 21 2018 aloisio@gmx.com
- Update to version 0.28.2
  Added features:
  * Add DRM_PRIME Format Handling and Display for RockChip MPP
    decoders
  * csputils: Add support for Display P3 primaries
  * demux: support multiple seekable cached ranges, display
    cache ranges on OSC
  * demux_playlist: support .url files (#5107)
  * dvb: Add multiple frontends support (up to 8)
  * dvb: implement parsing of modulation for VDR-style channels
    config
  * hwdec: add mediacodec hardware decoder for IMGFMT_MEDIACODEC
    frames,
  * rename mediacodec to mediacodec-copy
  * lua: integrate stats.lua script (bound to i/I by default)
  * vd_lavc: add support for nvdec hwaccel
  * vo_gpu: add android opengl backend
  * vo_gpu: initial d3d11 support
  * vo_gpu: vulkan support
  Removed features:
  * af: remove deprecated audio filters (channels, equalizer,
    pan, volume;
  * replacements in lavfi)
  * vf: remove most GPL video filters (crop, dsize, expand,
    flip, gradfun, mirror,
  * noformat, pullup, rotate, scale, stereo3d, yadif;
    replacements in lavfi)
  * vf_buffer: remove this filter
  * video: remove automatic stereo3d filter insertion
  * vo_gpu: remove hwdec_vaglx interop
  * vo_opengl: refactor into vo_gpu
  * vo_wayland: remove
  Added options and commands:
  * demux: add option to create CC tracks eagerly
    (--sub-create-cc-track)
  * options: add --start=none to reset previously set start time
  * options: add --vlang switch
  Changed options and commands:
  * cache: lower default size to 2*10MB
  * demux: bump the demuxer cache readahead duration to 10 hours
  * demux: use seekable cache for network by default, bump
    prefetch limit
  * msg: make --msg-level affect --log-file too
  * player/misc.c: allow both --length and --end to control play
    endpoint
  * player: match subtitles with language tags with
  - -sub-auto=exact
  * rename --opengl-hwdec-interop to --gpu-hwdec-interop (now
    mostly useless)
  * vd_lavc: prefer nvdec over vdpau with --hwdec=auto (better
    codec and surface
  * format support)
  * vd_lavc: rename --hwdec=rpi to --hwdec=mmal
  Removed options and commands:
  * options: remove --heartbeat-cmd and --heartbeat-interval
  * (incidentally fixes #4888)
  Fixes and Minor Enhancements
  * TOOLS/autoload.lua: add ogm, ogg and opus extensions
  * Use /dev/tty instead of stdin for terminal input (#4190)
  * audio: add audio softvol processing to AO (replaces
    previously GPL’d code)
  * audio: fix channel conversion with NA channels (e.g. with
    ALSA)
  * audio: fix missing volume update on init and reinit
  * csputils: Fix DCI P3 primaries white point
  * demux: don't allow subtitles to mess up buffered time display
  * demux: fix .cue files with audio files that contain attached
    pictures
  * demux: fix accounting for seekable ranges on track switches
    (fixes missing
  * audio when cycling through audio tracks with e.g. EDL,
  - -merge-files, ordered
  * chapters and youtube-dl pseudo DASH)
  * demux: fix crash with cue/ordered chapter files (#5027)
  * demux: speed up cache seeking with a coarse index
  * demux_lavf: always give libavformat the filename when probing
  * (helps with mp3 files)
  * demux_mkv: add V_SNOW tag to mkv_video_tags
  * dvb: Fix long channel switching: next/prev channel
  * dvb: fixes for ATSC tuning
  * lavc_conv: clamp timestamps to positive (#5047)
  * mp_image: always copy color attributes on hw download (#4804)
  * mp_image: select an explicit fallback for chroma location
    (#4804)
  * msg: bump log level of --log-file to -v -v
  * msg: reinterpret a bunch of message levels
  * osc: fix rare stack overflow when changing visibility mode
  * osdep/io: add android-related bullshit to fix files >2 GiB
  * player/playloop.c: respect playback start time when using
  - -loop-file
  * player: allow seeking in cached parts of unseekable streams
  * player: make track language matching case insensitive (#5272)
  * player: use start timestamp for ab-looping if --ab-loop-a is
    absent
  * player: when loading external file, always add all track
    types (#5132)
  * restore-old-bindings.conf: add old macOS/Wayland AXIS
    bindings
  * screenshot: create directories from template
  * scripting: report dlerror() output
  * sd_ass: accept RFC8081 font media types
  * sd_ass: accept otc as fallback OpenType collection file
    extension
  * stream_libarchive: work around various types of locale
    braindeath
  * (https://git.io/vbiFJ)
  * subprocess-win: don't change the mouse cursor when creating
    processes
  * video: add a hack to avoid missing subtitles with vf_sub
    (#5194)
  * video: fix alpha handling (#4983)
  * video: fix memory leaks (roughly 1 KB per decoded frame)
    with hwdec copy modes
  * video: fix rotation and deinterlace auto filters
  * video: properly pass through ICC data
  * vo: add support for externally driven renderloop and make
    wayland use it
  * (partially fixes display-sync under wayland; disables
    rendering when window
  * is invisible)
  * vo_gpu: change --tone-mapping-desaturate algorithm
  * vo_gpu: enable 3DLUTs in dumb mode
  * vo_gpu: fix gamma scale
  * vo_gpu: fix mobius tone mapping compatibility to GLSL 120
    (#5069)
  * vo_gpu: fix video sometimes not being rerendered on
    equalizer change
  * vo_gpu: kill off FBOTEX_FUZZY (#1814)
  * vo_gpu: opengl: fix possible screenshot window crash (#4905)
  * vo_gpu: opengl: use GLX_MESA_swap_control where available
  * vo_gpu: reduce the --alpha=blend-tiles checkerboard intensity
  * vo_gpu: win: remove exclusive-fullscreen detection hack
  * vo_lavc: remove messy delayed subtitle rendering logic
    (#4689)
  * wayland_common: implement output tracking, many cleanups and
    bugfixes
    (#4711)
  * ytdl_hook: don't prepend ytdl:// to non-youtube links in
    playlists (#5003)
- Refreshed mpv-make-ffmpeg-version-check-non-fatal.patch
- Dropped mpv-vaapi2.patch (no longer necessary)
* Tue Mar 20 2018 tchvatal@suse.com
- Do not enable smbclient twice, it is in normal opts too
* Wed Feb 14 2018 aloisio@gmx.com
- Update to version 0.27.2
  * This release contains an additional fix for CVE-2018-6360.
  Fixes and Minor Enhancements
  * ytdl_hook: whitelist subtitle URLs as well (#5456)
* Sat Feb 10 2018 aloisio@gmx.com
- Update to version 0.27.1
  * This release fixes CVE-2018-6360 (boo#1077894)
  Fixes and minor enhancements
  * ytdl_hook: whitelist protocols from urls retrieved from
    youtube-dl (#5456)
* Mon Nov 27 2017 mpluskal@suse.com
- Enable vapoursynth support
* Sun Nov 19 2017 mpluskal@suse.com
- Explicitly enable more options
- Sync with changes from home:X0F:HSF
* Thu Nov 16 2017 dimstar@opensuse.org
- Add mpv-vaapi2.patch: Fix build iwth vaapi 2.0. The patch is a
  backport of the commits 93c52b, f35126 and 2ecf24.
- Conditionalize use of %%desktop_database_post/postun and
  icon_theme_cache_post/postun to suse_version < 1330. The
  functionality has since been replaced by file triggers and the
  macros expand to %%nil.
* Mon Nov 13 2017 schwab@suse.de
- Fix BuildRequires for lua51
* Thu Nov  2 2017 mpluskal@suse.com
- Explicitly use python3 when building
- Enable libva on wayland
* Tue Oct 24 2017 aloisio@gmx.com
- Update mpv-bash-completion to 3.3.16
  * gen: make output reproducible by ensuring stable output of
    pairs() by wrapping it where it matters. (Closes #18)
* Wed Sep 13 2017 aloisio@gmx.com
- Update to version 0.27.0
  Added features:
  * libmpv: options: add a thread-safe way to notify option updates
  * vd_lavc/vo_opengl: support embedded ICC profiles
  * vo: rendering API abstraction for future non-GL video outputs
  * vo_opengl: add a gamut warning feature to highlight
    out-of-gamut colors (--gamut-warning)
  * vo_opengl: add direct rendering support (--vd-lavc-dr)
  * vo_opengl: implement (faster) compute shader based EWA kernel
  * vo_opengl: implement HLG OOTF inverse
  * vo_opengl: support HDR peak detection (--hdr-compute-peak)
  * vo_opengl: support float input pixel formats
  * vo_opengl: support loading custom user textures (#4586)
  * vo_opengl: support user compute shaders
  Removed features:
  * Remove video equalizer handling from vo_direct3d, vo_sdl,
    vo_vaapi, and vo_xv (GPL, not worth the effort to support legacy
    VOs)
  Added options and commands:
  * player: add --track-auto-selection option
  Changed options and commands:
  * input: use mnemonic names for mouse buttons, same as Qt:
    https://doc.qt.io/qt-5/qt.html#MouseButton-enum
  * options: change --loop semantics
  * player: make --lavfi-complex changeable at runtime
  * vf_eq: remove this filter (GPL; uses libavfilter’s eq filter
    now, with changed semantics)
  * video: change --deinterlace behavior
  * vo_opengl: generalize HDR tone mapping to gamut mapping,
  - -hdr-tone-mapping → --tone-mapping
  Removed options and commands:
  * --field-dominance (GPL-only author, no chance of relicensing)
  * input: drop deprecated "osd" command
  * options: drop --video-aspect-method=hybrid (GPL-only)
  Fixes and minor enhancements:
  * TOOLS/autocrop.lua: fix cropdetect black limit for 10-bit
    videos
  * TOOLS/lua/autodeint: update to lavfi-bridge
  * TOOLS/lua/status-line: improve and update
  * af_lavrresample: don't call swr_set_compensation() unless
    necessary (#4716)
  * ao_oss: fix period_size calculation (#4642)
  * ao_rsound: allow setting the host
  * audio: fix spdif mode
  * filter_kernels: correct spline64 kernel
  * options: fix --include (#4673)
  * player: fix --end with large values (#4650)
  * player: fix confusion in audio resync code (#4688)
  * player: make refresh seeks slightly more robust (#4757)
  * player: readd smi subtitle extension (#4626)
  * vd_lavc: change auto-probe order to prefer cuda over vdpau-copy
  * vd_lavc: fix device leak with copy-mode hwaccels (#4735)
  * vd_lavc: fix hwdec compatibility with yuvj420p formats
  * vd_lavc: fix mid-stream hwdec fallback
  * vf_vapoursynth: fix inverted sign and restore 10 bit support
    (#4720)
  * video: increase --monitorpixelaspect range
  * vo_opengl: adjust the rules for linearization (#4631)
  * vo_opengl: scale deband-grain to the signal range
  * vo_opengl: tone map on the maximum signal component
  * x11: fix that window could be resized when using embedding
    (#4784)
  * ytdl_hook: resolve relative paths when joining segment urls
    (#4827)
  * ytdl_hook: support fragments with relative paths, fixes
    segmented DASH
* Wed Aug 23 2017 alarrosa@suse.com
- Let mpv own /etc/mpv/scripts as a ghost dir so other packages
  can create it and install scripts there.
* Mon Aug 21 2017 tchvatal@suse.com
- Build only against luajit and not lua where possible
- Comment on why we depend on lua (for bash_completion generating)
- Explicitly enable libsmbclient
* Sun Aug 20 2017 aloisio@gmx.com
- Update mpv-bash-completion to 3.3.15
  * Fix af/vf filter argument expansion (#15)
  * Remove some invalid suggestions for some options (#14)
  * Recognize all --profile-style options as such and complete
    them
* Sat Aug 19 2017 aloisio@gmx.com
- Update mpv-bash-completion to 3.3.14
  * Reflect changed --list-options output for --vf-add-style
    options
- Update waf to 1.9.13
* Tue Aug 15 2017 dimstar@opensuse.org
- BuildRequire pkgconfig(lua5.1) instead of pkgconfig(lua-5.1): the
  .pc files has been normalized to match other distributions.
* Wed Jul 19 2017 aloisio@gmx.com
- Fixed Leap build WRT lua
- Removed shebang from bash-completion script
* Tue Jul 18 2017 9@cirno.systems
- Packaging changes:
  * Remove unnecessary build dependencies
  * Explicitly enable DVD and DVB features
  * Add libgbm, rubberband, uchardet
- Update to version 0.26.0
  * Built-in V4L TV support is disabled by default.
    av://v4l2 can be used instead.
  * Support for C plugins is now enabled by default (#4491).
  * Many more parts of the player are now licensed under LGPL,
    see Copyright file.
  Added features:
  * csputils: implement sony s-gamut
  * vo_opengl: add new HDR tone mapping algorithm
    (mobius, now default)
  * vo_opengl: hwdec_cuda: Support separate decode and display
    devices
  * vo_opengl: implement sony s-log1 and s-log2 trc
  * vo_opengl: implement support for OOTFs and non-display referred
    content
  Removed features:
  * vf_dlopen: remove this filter
  Added options and commands:
  * vo_opengl: add --tone-mapping-desaturate
  * vo_opengl: support tone-mapping-param for `clip`
  * ytdl_hook: add option to exclude URLs from being parsed
  Changed options and commands:
  * allow setting profile option with libmpv
  * audio: move replaygain control to top-level options
  * external_files: parse ~ in --{sub,audio}-paths
  * options: change --sub-fix-timing default to no (#4484)
  * options: expose string list actions for --sub-file option
  * options: slight cleanup of --sub-ass-style-override
    + signfs → scale
    + --sub-ass-style-override → --sub-ass-override
  * renamed the HDR TRCs `st2084` and `std-b67` to `pq` and `hlg`
    respectively
  * replace vf_format's `peak` suboption by `sig-peak`, which is
    relative to the reference white level instead of in cd/m^2
  * the following options change to append-by-default (and possibly
    separator): --script
  * video: change --video-aspect-method default value to `container`
  Deprecated options and commands:
  * m_option: deprecate multiple items for -add etc.
  * player: deprecate "osd" command
  * --audio-file-paths => --audio-file-path
  * --sub-paths => --sub-file-path
  * --opengl-shaders => --opengl-shader
  * --sub-paths => --sub-file-paths
  * the following options are deprecated for setting via API:
    + "script" (use "scripts")
    + "sub-file" (use "sub-files")
    + "audio-file" (use "audio-files")
    + "external-file" (use "external-files")
    (the compatibility hacks for this will be removed after this
    release)
  Removed options and commands:
  * chmap: remove misleading "downmix" channel layout name (#4545)
  * demux_lavf: remove --demuxer-lavf-cryptokey option (#4579)
  * input.conf: drop TV/DVB bindings
  * options: remove remaining deprecated audio device selection options
    + --alsa-device
    + --oss-device
    + --coreaudio-exclusive
    + --pulse-sink
    + --rsound-host/--rsound-port
    + --ao-sndio-device
    + --ao-wasapi-exclusive
    + --ao-wasapi-device
  * remove option --target-brightness
  * remove property "video-params/nom-peak"
  Fixes and minor enhancements:
  * TOOLS/lua/autoload.lua: actually sort files case insensitive (#4398)
  * TOOLS/lua/autoload.lua: ignores all files starting with "."
  * ao_pulse: reorder format choice to prefer float and S32 over S16 as fallback format
  * command: add missing change notification for playlist-shuffle (#4573)
  * demux_disc: fix bluray subtitle language retrieval (#4611)
  * demux_mkv: fix alpha with vp9 + libvpx
  * demux_mkv: support FFmpeg A_MS/ACM extensions
  * ipc-unix: don’t truncate the message on EAGAIN (#4452)
  * ipc: raise json nesting limit (#4394)
  * mpv_identify: replace deprecated fps property (#4550)
  * options/path: fallback to USERPROFILE if HOME isn't set
  * player: close audio device on no audio track
  * player: fix potential segfault when playing dvd:// with DVD disabled (#4393)
  * player: prevent seek position to jump around adjacent keyframes, e.g. when dragging the OSC bar on short videos (#4183)
  * vo_opengl: bump up SHADER_MAX_HOOKS and MAX_TEXTURE_HOOKS to 64
  * vo_opengl: correct off-by-one in scale=oversample
  * vo_opengl: do not use vaapi-over-GLX (#4555)
  * vo_opengl: fall back to ordered dither instead of blowing up (#4519)
  * vo_opengl: tone map in linear XYZ instead of RGB
  * x11: add 128x128 sized icon support
  * ytdl_hook: add a header to support geo-bypass
  * ytdl_hook: don't override start time set by saved state
  * ytdl_hook: don't override user-set start time
  * ytdl_hook: treat single-entry playlists as a single video
* Mon May 22 2017 tchvatal@suse.com
- Depend on lua-5.1 as 5.3 is incompatible wrt bsc#1040034
* Tue May  9 2017 tchvatal@suse.com
- Refresh patch mpv-make-ffmpeg-version-check-non-fatal.patch
  * Rather delete the warning as whole, in OBS concept we detect
    abi changes and it misleads the users of stable distributions
    to worry something broke
* Tue May  2 2017 tchvatal@suse.com
- Remove the pdf build, it is same as manpage
- Switch to python3 subpkgs as we use python3 anyway (Fixes TW build)
* Sun Apr 23 2017 aloisio@gmx.com
- Dropped openal. It's pointless these days and it creates
  a problem when used with pulse (gh#mpv-player/mpv#4311)
- Removed portaudio requirement (support was dropped in
  0.8.0!)
* Sun Apr 23 2017 aloisio@gmx.com
- Update to version 0.25.0
  * Support for some optical media functionality (DVD/CD) is now
    disabled by default.
  * More parts of the player are now licensed under LGPL. In
    particular:
    + OSD symbol font
    + ass_mp, sd_ass
    + common.h
    + demux/packet
    + demux_mkv (with minor exceptions), ebml, matroska.h
    + sd_lavc
    + sub/osd
    Thanks to all contributors who have agreed to relicensing of
    their changes! See #2033 for details.
  * Starting with this release, releases will be tagged on the
    master branch. The release/current branch is thus abandoned.
  Added features:
  * TOOLS: add acompressor.lua script for runtime acompressor ffmpeg
    filter control
  * dvb: add support for DVB-T2
  * lavfi: support hwdec filters for --lavfi-complex
  * osc: add volume button (mouse wheel to change volume)
  * sub: add SDH subtitle filter
  * vo_opengl: add experimental vdpauglx backend
  Removed features:
  * image_writer: remove useless formats (PPM, PGM, TGA)
  * af_drc: remove (use --af=acompressor instead; higher quality)
  Added options and commands:
  * --demuxer-lavf-probe-info
  * --sub-filter-sdh, --sub-filter-sdh-harder
  * add automatic libavfilter bridges to option parsing
  * command: add better runtime filter toggling method
  * command: add demux-start-time property
  * command: add property notifications for hwdec properties (#4289)
  * input: add "async" flag
  * osc: add user_opts.boxmaxchars for box layout title limit
  * player: add --keep-open-pause=no option
  * va_vavpp: reversal-bug=no
  * vo_opengl: --opengl-es=force2
  * vo_opengl: add --opengl-shader-cache-dir option for caching
    shaders on disk (mostly for ANGLE)
  * vo_opengl: angle: add --angle-flip to set the ANGLE present model
  Changed options and features:
  * command: update sub-fps etc. options on runtime changes
  * vo_opengl: prefer X11 backends over Wayland backends
  * options: change --audio-file-auto default to not to load any
    files
  Deprecated options and features:
  * audio: deprecate most non-lavfi audio filters
    (channels, equalizer, pan, volume)
  * video: deprecate almost all non-lavfi video filters
    (buffer, crop, dlopen, dsize, eq, expand, flip, gradfun, mirror,
    noformat, pullup, rotate, scale, stereo3d, sub, yadif)
  * options: deprecate --loop semantics (planned alias to
  - -loop-file)
  Fixes and minor enhancements:
  * ao_alsa: close lost audio devices (#4189)
  * ao_alsa: filter fewer devices
  * ao_alsa: fix an error check (#4188)
  * ao_jack: update latency on buffer_size/graph change
  * ao_wasapi: do not pass nonsense to drivers with double precision
    formats
  * ass_mp: reallocate cached subtitle image data on format changes
    (#4325)
  * build: decouple dvdnav check from dvdread (#4290)
  * build: encode_lavc: fix build failure after libavcodec major bump
  * build: fix build with HAVE_GL==0
  * build: replace android-gl check with a standard GLES3 check
  * build: update bundled waf to 1.9.8
  * build: vd_lavc: fix potential build failure with vaapi
  * demux_lavf: disable half-working mp4 edit list support in
    libavcodec
  * demux_lavf: skip avformat_find_stream_info() for some formats
    (hls, mp4, mkv by default)
  * etc/encoding_profiles.conf: update and remove deprecated stuff
  * etc/mpv.conf: remove deprecated options
  * external_files: actually try to autoload from fallback paths
  * external_files: enable autoloading with URLs (#3264)
  * image_writer: make it work with libavcodec's jpg encoder
  * osc: bottom/topbar: add fullscreen button
  * osc: bottom/topbar: don't clip title vertically
  * osc: bottom/topbar: increase timecodes width a bit (#3952)
  * osc: fix PlayResX undefined warning when aspect is 0
  * osc: fix window dragging with showwindowed=no (#1819)
  * osc: make title configurable and use property expansion on it
    (#4221)
  * osc: refactor osc message scaling (#4081, #4083, #4102)
  * player: don't block playback stop when seeking
  * player: enable "buffering" pausing for DASH streams too
  * player: fix core-idle and eof-reached update notifcations
  * player: make screenshot commands honor the async flag (#4250)
  * player: reduce blocking on VO when switching pause (#4152)
  * sd_ass: disable --sub-fix-timing if sub style override is fully
    disabled
  * stream/stream_dvdnav: don't ignore setting title (#4283)
  * stream_dvd: fix subs/audio detection on DVDs containing
    multi-PGC titles
  * vf_vavpp: add advanced deint bug compatibility for Intel vaapi
    drivers
  * vf_vavpp: fix first-field mode
  * vo_opengl: fix crash with temporal dithering in dumb mode
  * vo_opengl: hwdec_d3d11egl: make it work with some ANGLE DLL
    versions
  * vo_x11: reduce flickering on playlist navigation
  * wayland: correctly map mouse buttons
* Wed Apr 19 2017 tchvatal@suse.com
- Use localy present waf to adhere upstream requirements
* Sat Apr 15 2017 tchvatal@suse.com
- Enable luajit on aarch64 and update bit the conditional for wayland
* Fri Apr 14 2017 aloisio@gmx.com
- Update mpv-bash-completion to 3.3.13
  * Dynamic completion for --drm-connector based on currently
    connected displays
  * Fixes for options audio-demuxer, audio-spdif, cscale-window,
    demuxer, dscale, dscale-window, opengl-hwdec-interop,
    scale-window, sub-demuxer
* Fri Apr  7 2017 aloisio@gmx.com
- Update mpv-bash-completion to 3.3.12
  * Implement feature request #12: Previoiusly, the --profile
    option would only list built-in profiles and not profiles
    defined in configuration files because at build time, mpv is
    called with the --no-config option. Now, --profile completions
    are obtained by calling mpv directly, at completion run time,
    and the completions now include profiles defined in
    configuration files.
* Sun Mar 26 2017 aloisio@gmx.com
- Update mpv-bash-completion to 3.3.11
  * Enable correct completion of the options --ad, --vd,
  - -oac, --ovc which where hitherto broken.
* Sat Mar 11 2017 aloisio@gmx.com
- Update mpv-bash-completion to 3.3.10
  * improve completion for file-specific options
  * do not assume option types are always populated
- Fixed Factory build
* Sun Feb 12 2017 aloisio@gmx.com
- Update to version 0.24.0
  Added features:
  * player: add experimental C plugin interface
  * player: add experimental stream recording feature
    (--record-file)
  * player: add prefetching of the next playlist entry
    (--prefetch-playlist; does NOT work with URLs resolved by
    youtube-dl)
  * stream_lavf: add support for data URIs (#4058)
  * vaapi: add support for 10-bit video formats (requires
    patched Mesa and capable hardware)
  * x11: pseudo HiDPI scaling
  Added options and commands:
  * sub: add --sub-justify and --sub-ass-justify options
  * sub: add option to force using video resolution for image
    subtitles (--image-subs-video-resolution)
  Changed options and commands:
  * command: rename framedrop properties
    + drop-frame-count → decoder-frame-drop-count
    + vo-drop-frame-count → frame-drop-count
  * input.conf: change "L" to change loop-file by default
  Deprecated options and commands:
  * --hwdec-preload (replaced with --opengl-hwdec-interop)
  Removed options and commands:
  * options: drop deprecated --sub-codepage syntax
  * options: drop deprecated --vd/--ad codecs selection
    features
  * player: remove --stream-capture option/property
  Fixes and minor enhancements:
  * ad_spdif: fix obscure cases of AC3 passthrough (e.g. 44100
    Hz AC3)
  * ao_oss: use --audio-device if --oss-device isn't set
    (#4122)
  * build: fix --disable-gl if cuda is enabled
  * build: rpi: rely on pkgconfig for compiler flags to ease
    cross compilation
  * charset_conv: fallback to interpreting subs as latin1 if
    iconv fails
  * charset_conv: fix "auto" fallback with uchardet not
    compiled (#3954)
  * client API: fix freeze when destroying mpv_handle before
    mpv_initialize
  * client API: fix mpv_set_property() return value before
    init (#3988)
  * command: fix potential crash for script-binding with
    multi-commands
  * command: nicer OSD formatting for loop-file
  * command: shorten long playlists on OSD
  * config: do not resolve default profile during "include"
    processing (#4024)
  * cuda: fix 10 bit decoding
  * cue: accept lower-case cue commands (#4057)
  * demux_mkv: any reference makes a frame not a keyframe
    (fixes seeking in WebM files with alpha channel)
  * lavfi: slightly better disconnected output handling (#4118)
  * lua: close directory after reading its entries (#4045)
  * osc: allow playlist buttons when looping (#4092)
  * osc: bottom/topbar: clip title instead of stretching
  * osc: bottombar/topbar: make chapter markers slightly bigger
  * osc: box: clip with ellipsis after too much stretching
  * osc: fix crashes related to field eventresponder being nil
    (#3210)
  * player: add .scc subtitle extension
  * stream_bluray: use proper 0-based index
  * sub: remove .txt as text subtitle extension
  * tv: fix segfaults on TV input (#4096)
  * vaapi: set libva > 0.39.4 message callbacks to prevent it
    from printing messages to the terminal
  * vd_lavc: improved fallback behavior for --hwdec=cuda
    (#3914)
  * vdpau: reject decoding of non-4:2:0 (would decode to
    garbage)
  * vf_lavfi: don't crash with VOs without hardware decoding
    support (#4064)
  * vo_opengl, vo_opengl_cb: better hwdec interop backend
    selection
  * vo_opengl: angle: rewrite with custom swap chain (fixes
    problems with e.g. 24 fps video on 24 Hz monitors, avoids
    problems with DirectComposition, enables "screenshot window"
    command on Windows 8 and newer)
  * vo_opengl: partially fix rotation for 4:2:2 content
  * vo_opengl: x11egl: fix alpha mode
  * wayland: fix high CPU usage with mpv paused and visible
  * ytdl_hook, edl: implement pseudo-DASH support
  * ytdl_hook: add non-dash fallbacks to default formats
  * ytdl_hook: fix opening hitbox.tv rtmp stream
  * ytdl_hook: respect --no-audio, don't force-select track
  * ytdl_hook: support livestream segmented DASH VODs
  * ytdl_hook: support segmented dash
- Fixed mpv executable version quirk and remove ambiguity
  concerning the %%{version} macro.
- Updated ffmpeg libraries version requirements to 3.2.2
* Thu Jan 19 2017 jengelh@inai.de
- Fixup wrong description
* Thu Jan 19 2017 aloisio@gmx.com
- Updated embedded mpv-bash-completion to 3.3.8
  * FIXED: --{ and --} got treated as flags, completing to
  - -{=yes|no and --}=yes|no, respectively, due to a change in
    upstream option typing, which is a command line syntax error.
* Tue Jan  3 2017 aloisio@gmx.com
- Further version requirement fixes
* Tue Jan  3 2017 aloisio@gmx.com
- Fixed version requirement in the bash-completion
  subpackage
* Tue Jan  3 2017 tchvatal@suse.com
- Use system waf, seems not to break for now anymore
- Use correct licenses in all subpkgs
* Tue Jan  3 2017 aloisio@gmx.com
- Fixed minor details for the mpv-bash-completion subpackage
* Mon Jan  2 2017 tchvatal@suse.com
- Split the completion to separate subpackage and build it in obs not
  during post
* Mon Jan  2 2017 aloisio@gmx.com
- Added mpv-bash-completion-3.3.7.tar.gz to generate
  a bash-completion script
* Sun Dec 25 2016 aloisio@gmx.com
- Update to version 0.23.0
  * Now requires at least FFmpeg 3.2.2.
  Changed features:
  * vo_rpi: partially undeprecate
  Added features:
  * vo_opengl: hwdec_cuda: Support P016 output surfaces
  Removed features:
  * charset_conv: drop enca and libguess support in favor of
    uchardet
  * vf_vdpaurb: remove this filter in favor of --hwdec=vdpau-copy
  Added options and commands:
  * TOOLS/autoload: allow disabling through script-opts
  * demux, stream: add --access-references to prevent opening
    referenced files
  Deprecated options and commands:
  * options: deprecate codec family selection in --vd/--ad
  Removed options and commands
  * options: remove deprecated sub-option handling for --vo
    and --ao
  Fixes and minor enhancements:
  * Windows: window styles improvements (allow minimizing
    borderless/fullscreen window) (#2229, #2451)
  * ad_spdif: Fix crash when spdif muxer is not available
  * audio: fix --audio-stream-silence with ao_alsa
  * audio: fix --audio-stream-silence with ao_wasapi
  * build: drop build-time dependency on Perl
  * build: support linking ANGLE (previously loaded dynamically)
  * d3d11va: unconditionally load D3D DLLs (#3348)
  * demux_mkv: fix seeking in some broken files (#3920)
  * hwdec_cuda: allow building without CUDA SDK (load CUDA
    dynamically)
  * osc: don't hide playlist buttons, just disable
  * osc: fix possible race condition in right timecode
  * osc: topbar: use same styles as bottombar
  * player: don't print format detection error when aborting
    loading
  * vdpau: fix vaapi probing if libvdpau-va-gl1 is present
  * video: use demuxer-signaled duration for last video
    frame (#3924)
* Sun Nov 20 2016 aloisio@gmx.com
- Update to version 0.22.0
  Added features:
  * audio/out: add AudioUnit output driver for iOS
  * demux_mkv: parse Matroska colorimetry metadata
  * filter_kernels: add ability to taper kernels/windows, add
    tukey window
  * osc: add seekbarstyle=knob (#2365)
  * video/out: add tct as modern caca alternative for
    true-color and 256-color terminals
  * video: add --hwdec=vdpau-copy mode
  Deprecated features:
  * vf_vdpaurb: deprecated in favor of --hwdec=vdpau-copy
  Added options and commands
  * --opengl-early-flush=auto
  * --scale-taper, --scale-wtaper
  * --scale-wblur
  * macOS: --hidpi-window-scale (#3716)
  * osc: add script message handlers for
    chapter/track/playlists
  Fixes and Minor Enhancements
  * Apply --autofit-larger after --autofit-smaller (#3753)
  * Set subtitle track title to indicate hearing/visual
    impaired tracks
  * ao_alsa: disable chmap API use for mono/stereo (#2905,
    [#3045])
  * build: add required failure message for libavfilter check
    (#3692)
  * build: fix compilation with mingw-w64/Clang (#3800)
  * build: make VideoToolbox available on iOS
  * command: fix reset-on-next-file=all and tv-freq option
    (#3708)
  * command: if window-scale can't be set properly, set it as
    option (#3724)
  * demux_mkv: don't recursively resolve timeline for opened
    reference files
  * demux_mkv: fix ordered chapter sources with ordered
    editions
  * opengl: compile against iOS OpenGLES implementation
  * options: handle legacy no-* sub-options
  * osc: add alpha animation to tooltip (fix lingering tooltip)
  * osc: change default deadzonesize to 0.5
  * osc: don't wrap the title
  * osc: fix crash after reaching a certain position in
    limited lists (#3691)
  * osc: fix crash with no chapters
  * osc: fix crashes when dragging seekbar across file changes
    (#3210)
  * osc: fix displaying only half of the entries when at the
    end of a list
  * osc: fix missing chapter ticks with seekbarstyle=bar
  * osc: slimbox: fix clipping with seekbarstyle=bar (#3737)
  * osc: top/bottombar: also scale when min-width is reached
    to match box/slimbox behavior
  * osc: top/bottombar: dynamically size timecodes according
    to timems
  * osc: top/bottombar: rescale layout to same size with
    scale=1
  * osc: top/bottombar: scale title if too large like box
  * player: consistently initialize screensaver state with
  - -force-window
  * player: enable no-video subtitle display on coverart too
  * player: make --start-time work with --rebase-start-time=no
  * player: make sure non-video subtitle rendering is reset if
    video resumes (#3770)
  * player: removing last playlist entry while looping should
    not stop (#3808)
  * player: show subtitles on VO if --force-window is used
    (#3684)
  * player: speed up audio/video re-sync when there is a huge
    delay
  * vdpau: fix hwdec uninit (#3788)
  * vo_opengl: blend against background color for --alpha=blend
  * vo_opengl: context_rpi: fix stdatomic usage (#3699)
  * vo_opengl: fix --blend-subtitles handling (#3773)
  * vo_opengl: fix redrawing with hardware decoding (#3773)
  * vo_opengl: partially re-enable glFlush() calls (#3670)
  * ytdl_hook: sort chapters by time
* Fri Nov  4 2016 tchvatal@suse.com
- Add patch to not require equal libav soname version we were built with
  OBS rebuilds packages as needed and it is over the head bsc#1012600
  * mpv-make-ffmpeg-version-check-non-fatal.patch
* Wed Oct 19 2016 aloisio@gmx.com
- Update to version 0.21.0
  Added features:
  * config: allow profile forward-references in default profile
  * demux_lavf: "support" mov edit lists and log errors if
    used (FFmpeg only)
  * hwdec: Add support for CUDA and cuvid/NvDecode (mostly
    useful on Linux where VDPAU still lacks HEVC Main 10
    support; keep using DXVA2 on Windows)
  * osc: add right-click behavior to playlist and chapter
    buttons
  * osc: add user-alterable margin for top/bottombar
  * rpi: add --hwdec=rpi-copy (#3604)
  * sd_lavc: enable teletext
  * vaapi: support drm devices when running in vaapi-copy mode
  * vd_lavc: Add hwdec wrapper for crystalhd
  * vo_opengl: add hw overlay support and use it for RPI
  * vo_opengl: basic mali fbdev support
  * vo_opengl: rpi: merge vo_rpi features
  Removed features:
  * vo_opengl: remove pre/post/scale-shaders in favor of
    user-shaders
  Deprecated features:
  * config: deprecate ao and vo auto-profiles
  * vo_rpi: deprecate this VO
    Added options and commands:
  * add --teletext-page option
  * af_pan: add af-command support to change the matrix
  * af_rubberband: add af-command and option to change the
    pitch
  * command: add a load-script command
  * command: add a video-dec-params property
  * command: add an apply-profile command
  * command: add audio-pts property to get the audio pts
  * command: add options to property list
  * command: add sub-text property for current subtitle text
  * command: export profile list as a property (#977)
  * options: add --hwdec=yes as alias for --hwdec=auto
  * player: add --player-operation-mode=pseudo-gui
  * player: add --video-osd=no option to disable video OSD
    (#3387)
  * player: add --watch-later-directory option
  * stream_bluray: select title by playlist
    (bd://mpls/[playlist])
  * vo_opengl: disable glFlush() by default, and add an option
    to enable it for testing
  Changed options and commands:
  * af_rubberband: default to channels=together
  * command: allow absolute seeks relative to end of stream
  * command: make bitrate properties observable
  * command: make most options observable
  * msg: make --log-file and --dump-stats accept config path
    expansion (#3591)
  * options: deprecate --playlist-pos to --playlist-start
  * options: make input options generally runtime-settable
  * options: rename subtitle options (--sub-text- → --sub;
  - -ass- → --sub-ass-)
  * osc: change default layout to bottombar, seekbarstyle to
    bar, use larger scalewindowed and scalefullscreen
  * player: make --terminal, --log-file, --dump-stats, --osc,
  - -ytdl, --audio-*, --priority, --stop-screensaver (#3615)
    settable at runtime
  * vo_drm: change CLI options
    + Change connector selection to accept human readable
    names (such as eDP-1, HDMI-A-2) rather than arbitrary
    numbers.
    + Change GPU selection to accept GPU number rather than
    device paths.
    + Merge connector and GPU selection into one
  - -drm-connector.
    + Add support for --drm-connector=help.
    + Add support for --drm-* in EGL backend.
  * vo_opengl: rename 3dlut-size to icc-3dlut-size
  Removed options and commands:
  * command: remove hwdec-active and hwdec-detected properties
  * command: remove vo-cmdline
  * options: drop unreferenced --bluray-angle option
  * vo, ao: disable positional parameter suboptions
  * vo_xv: replace no-colorkey with ck-method=none
  Deprecated options and commands:
  * all VOs and AOs: deprecate sub-options, add them as global
    options
  * command: deprecate "cache" property, replace with
    "cache-percent"
  * deprecate --vo-defaults
  * deprecate --vo=opengl-hq alias in favor of opengl-hq
    profile
  * options: deprecate --mute=auto
  * vo_direct3d: deprecate direct3d_shaders alias, use shaders
    by default
  * vo_opengl: deprecate 'drm-egl' backend and introduce 'drm'
    instead
  Fixes and minor enhancements:
  * TOOLS/zsh.pl: die if we can't parse main options
  * TOOLS/zsh.pl: don't filter files by extension (#2273)
  * ao_alsa: try to fallback to "hdmi" before "iec958" for
    spdif
  * ao_rsound: fix compilation (#3501)
  * aspect: use nominal width instead of actual width for
    video-unscaled
  * audio/out: prevent underruns with spdif under certain
    conditions
  * audio: fix late audio start (#3610)
  * audio: fix missed wakeup when changing audio output device
  * audio: fix segfault when yanking USB DAC
  * charset_conv: Use CP949 instead of EUC-KR
  * command: don't log "ignore" command with -v verbosity
  * command: try selecting the next track if track switching
    fails (#3446)
  * demux_mkv: don't crash if --ordered-chapters-files fails
  * displayconfig: treat a refresh rate of 1 as invalid
  * ipc: log when listening to IPC socket (#3598)
  * macOS: fix fullscreen regression on 10.11 and newer (#3364)
  * mp_image: fix clearing to black with p010 format
  * osc: Fix scaling issues when toggling fullscreen (#3429)
  * osc: align text vertically in top/bottombar (#2093)
  * osc: change seekbar background's alpha scaling
  * osc: fix display of chapters and playlist scaling
  * osc: move tooltip to inside seekbar for top/bottombar
  * osc: show playlist/chapter list on prev/next instead of osd
  * path: default ~~ paths to home directory (#3591)
  * player: do not let pseudo-gui override user config settings
  * player: enable reading from stdin after loading input.conf
  * player: fix instant subtitle refresh on track switches
  * player: make --force-window work with opengl-cb
  * stream_file: don't use poll() on directories (would hang
    on macOS; #3530, #3649)
  * stream_lavf: fix determining seekability (#1701)
  * sub: actually apply text alignment options to non-ASS
    subtitles
  * terminal-win: support modifier keys in console input
    (#3625)
  * vo_drm: fix segfault when using invalid card
  * vo_opengl: apply 90° rotation to chroma texture size
    (#3568)
  * vo_opengl: fix incorrect video rendering after vdpau
    preemption recovery
  * vo_opengl: partially fix dumb-mode cropping with rotation
  * vo_opengl: rpi: use overlay for yuv420p too
  * w32_common: initialize playback status as soon as possible
    (#3482)
  * wayland: reject resize events with either dimension being
    0 (#3679)
  * x11: fix external fullscreen update (#3570)
  * ytdl_hook: Add title to playlist items if available
  * ytdl_hook: Set aspect ratio for anamorphic video
  * ytdl_hook: Support playlist entries without subtitles
  * ytdl_hook: add chapters by parsing video's description
  * ytdl_hook: don't add subtitles with unknown duration
  * ytdl_hook: temporarily force disable dash segments formats
- Update waf to 1.9.5
* Sat Oct 15 2016 mpluskal@suse.com
- Enable libarchive support
* Fri Sep  2 2016 idonmez@suse.com
- Add exact dependency on all libav* packages not just libavcodec.
* Fri Aug 26 2016 aloisio@gmx.com
- Update to version 0.20.0
  Added options and commands:
  * aspect: add --video-unscaled=downscale-big
  * player: add --image-display-duration option to control
    duration of image display (#3425)
  * vo_opengl: angle: new flag (dcomposition) to control
    DirectComposition
  Fixes and minor enhancements:
  * af_lavrresample: fix error if resampler could not be
    recreated
  * audio: avoid missed wakeups with ab-loops
  * audio: do not apply --audio-channels if spdif passthrough is
    in use (#3445)
  * cache: don't use a backbuffer if the cache is as large as
    the file
  * command: prevent O(n^2) behaviour for playlist property
  * demux: close underlying stream if it's fully read anyway
    (#3456)
  * demux: fix undefined behavior with ogg metadata update
    (#3451)
  * player: make looping slightly more seamless
  * player: refresh very low framerate video on filter changes
    (#3435)
  * stream_memory: disable stream cache
  * vf_rotate: allow arbitrary rotation (#3434)
  * vo: be more trusting to estimated display FPS (#3433)
  * w32_common: use hooks to detect parent window resize
  * x11: work around mutter fullscreen issue (#2072)
  * This listing is not complete. Check
    DOCS/client-api-changes.rst for a history
    of changes to the client API, and DOCS/interface-changes.rst
    for a history of changes to other user-visible interfaces.
* Mon Aug 15 2016 aloisio@gmx.com
- Update to version 0.19.0
  Build system changes:
  * build: add --htmldir option
  * build: always require atomics
  * wscript: add proper unversioned SONAME for Android
  New features:
  * client API: add stream_cb API for user-defined stream
    implementations (bumps client API version to 1.22)
  * vf_d3d11vpp: add video processor selection
  * videotoolbox: add --hwdec=videotoolbox-copy for h/w
    accelerated decoding with video filters
  * vo_opengl: add a tscale=linear direct implementation
  Removed features:
  * audio/filter: remove delay audio filter
  Added options and commands:
  * command: add filename/no-ext sub-property that returns
    filename without extension (#3404)
  * command: add properties for HDR metadata
  * command: add replaygain information properties to
    track-list
  * options: add vp9 to --hwdec-codecs
  * player: add --audio-stream-silence
  * player: add --audio-wait-open
  * player: add --no-autoload-files
  * videotoolbox: add yuv420p to --videotoolbox-format
  Changed options and commands:
  * options: un-restrict --audio-delay
  * use - as command-name separator everywhere
  * vo_opengl: reduce default 3dlut-size to 64x64x64 (since
    accuracy is improved)
  Deprecated options and commands:
  * deprecate "balance" option/property (no replacement)
  Fixes and Minor Enhancements:
  * Windows: don't wait for GUI thread when polling for
    events (#3393)
  * af_lavcac3enc: error out properly if encoding fails
  * af_volume: don't let softvol overwrite af_volume
    volumedb sub-option
  * ao_pulse: fix some volume control rounding issues
  * ao_wasapi: in exclusive mode, do not output multichannel
    by default
  * audio: add heuristic to move auto-downmixing before
    other filters
  * audio: show an osd bar when changing ao-volume
  * demux: make ALBUM replaygain tags optional (#3405)
  * demux_raw: fix small typo to add s16be support
  * demux_timeline: restore mkv edition switching
  * libarchive: sanitize non-UTF8 archive entries
  * macOS/vo_opengl: fix crash when glctx is NULL during
    init (#3360)
  * player: disable display-sync with spdif transcoding
  * player: do not cut off terminal status line if it
    contains newlines (#3340)
  * player: fix display-sync timing if audio resumes slowly
  * player: improve instant track switching (#3392)
  * player: improve non-hr seeking with external audio tracks
  * player: offset demuxer on start/seek properly with
    audio/sub delay
  * player: sync audio as well when enabling it mid-stream
  * stream/stream_bluray: display list of available titles
    in verbose mode
  * sub: don't potentially discard too many subtitles on seek
  * video: respect --deinterlace=auto
  * vo_direct3d: add missing header (fixes Cygwin build)
  * vo_opengl: angle: try D3D9 when D3D11 fails eglInitialize
  * vo_opengl: angle: use WARP if there are no hw adapters
    (makes it work on Windows 7 without hardware-accelerated
    graphics)
  * vo_opengl: increase 3DLUT accuracy at smaller LUT sizes
  * vo_opengl: remove the 3dlut-size npot2 restriction
  * vo_wayland: fix high CPU usage due to busy polling
  * wayland_common: clip window size to the display output
    size
  * wayland_common: fix crashes when switching to fullscreen
    before the video output is fully initialized
  * wayland_common: fix fullscreen image switching bug
  * wayland_common: prevent black bars on most non-native
    aspect ratios
  * wayland_common: remove untested/unusable wayland dnd code
  * win32: mpv.rc: re-add version info
  * x11: skip ICC update on every window move
  * ytdl: Error out with http_dash_segments (unsupported for
    now)
- Updated waf to 1.9.2
* Tue Jul 12 2016 tchvatal@suse.com
- Update waf to 1.9.1
* Tue Jul 12 2016 mpluskal@suse.com
- Force rebuilding with every minor update of ffmpeg
* Sun Jul 10 2016 aloisio@gmx.com
- Update to version 0.18.1
  * Note: Running mpv with different versions of the
    FFmpeg/Libav libraries than it was compiled with
    is no longer supported. Even supposedly ABI-compatible
    versions have been a source of trouble, and it creates
    far too much complexity with little to no benefit,
    coupled with absurd and unusable FFmpeg API artifacts.
    Instead, mpv will exit with an error when such a
    situation is detected.
    This simply means that mpv needs to be rebuilt whenever
    FFmpeg libraries change.
  New Features:
  * d3d: implement screenshots for --hwdec=d3d11va
  * vo_opengl: add output_size uniform to custom shader
  * vo_opengl: implement the Panasonic V-Log function
    (#3157)
  * vo_opengl: implement ARIB STD-B68 (HLG) HDR TRC
  Options and oommands:
  * command: pack sub image data in overlay-add command
  * options: deprecate --heartbeat-cmd
  * audio: deprecate --softvol
  * audio: drop --softvol=no and --softvol=auto (#3322)
  Fixes and minor enhancements:
  * video: fix deinterlace filter handling on pixel
    format changes
  * x11: silence xdg-screensaver
  * vo_opengl: angle: update the swapchain on resize
    (#3301)
  * vo_opengl: error out gracefully when trying to use
    FBOs without FBO API
  * vd_lavc: expose mastering display side data reference
    peak (improves results with HDR content)
  * vo_opengl: generalize HDR tone mapping mechanism
    (#3293)
  * vo_opengl: don't constantly resize the output FBO
  * vo_opengl: use ringbuffer of PBOs
  * Windows: make WM_NCHITTEST simpler and more accurate
  * ao_oss: do not add an entry to audio-device-list if
    device file missing
  * dec_audio: fix segment boudnary switching
  * ao_lavc, vo_lavc: Migrate to new FFmpeg encoding API
  * vo_opengl: explicitly use main framebuffer when
    reading window content (#3284)
  * vo_xv: fix behavior with odd sizes
  * audio: insert auto-inserted filters at end of chain
  * x11: add missing FocusChangeMask (disables key repeat
    when losing focus while a key is down)
  * ao_coreaudio: error out when selecting invalid device
  * ad_lavc: work around misbehavior of some FFmpeg
    decoders like wmapro (#3297)
  * player: cut off status line on terminal width
* Sun Jun 26 2016 virtuousfox@gmail.com
- Remove mpv_gpl3 Packman condition due to upstream's decision
  to drop "prescaling" code in favour of generic shader hooks.
* Sat Jun 25 2016 aloisio@gmx.com
- Update to version 0.18.0
  Build System Changes:
  * build: Do not link to libGL for egl-drm
  * build: also use the iconv check on FreeBSD
  * build: don't install tests, only build them
  * build: re-enable encoding mode by default
  * vo_opengl: hwdec: remove build-dependency on dxva2 (#3150)
  * wscript: make at least 1 OpenGL output mandatory
  New features:
  * csputils: add SMPTE ST2084 support
  * demux_mkv: support Matroska webvtt (#3247)
  * demux_playlist: read directories recursively
  * stream_memory: add hex:// protocol
  * vf_crop: support opaque hardware decoding formats
  * vf_d3d11vpp: add a D3D11 video processor filter
  * vo_opengl: D3D11VA + ANGLE interop
  * vo_opengl: add an angle-es2 backend
  * vo_opengl: angle: dynamically load ANGLE
  * vo_opengl: d3d11egl: native NV12 sampling support
  * vo_opengl: enable color management on GLES
  * vo_opengl: implement HDR (SMPTE ST2084)
  * vo_opengl: implement tone mapping algorithms
  * vo_opengl: make PBOs work on GLES 3.x
  * vo_opengl: support external user hooks, enhancing the
    flexibility of user shaders
  * vo_opengl: vdpau interop without RGB conversion
  * wayland: implement HIDPI support
  Removed features:
  * vo_opengl: remove nnedi3 prescaler (replaced by user shaders)
  * vo_opengl: remove prescaling framework with superxbr prescaler
    (replaced by user shaders)
  Added options and commands:
  * Windows: make taskbar progress indication optional (#2535)
  * af_lavcac3enc: make encoder configurable
  * command: add playlist-pos-1 property (#2828)
  * command: introduce hwdec-current and hwdec-interop properties.
  * options: add --fit-border video option (currently Windows only)
  * video: add --hwdec=auto-copy mode
  * vo_opengl: always autoselect ANGLE as backend if available
  * vo_opengl: expose performance timers as properties
  * x11: add --x11-bypass-compositor=never
  * x11: extend --x11-bypass-compositor with fs-only option (#2582)
  Changed options and commands:
  * command: allow setting panscan etc. properties if no video is
    active
  * command: don't seek immediately when setting a-b loop while
    paused
  * command: if only ab-loop-b is set, loop from start of file
  * options: --geometry: center window position after applying
    size (#2397)
  * player: loop on end of file if ab-loop-b is unset
  * sd_add: replace --sub-ass=no with --ass-style-override=strip
  Removed options and commands:
  * vo_opengl: remove non-working rgb/rgba FBO formats
  Fixes and minor enhancements:
  * TOOLS/zsh.pl: add .f4v extension in zsh completions
  * TOOLS/zsh.pl: complete --audio-device
  * Windows: center window on original window center on resize to
    fit screen
  * Windows: fix size calculations for window resize (#2935)
  * Windows: fix wrong behavior with window-scale when window size
    exceeds screen size
  * Windows: make VOCTRL_SET_UNFS_WINDOW_SIZE resize the window
    around its center (#3164)
  * af_lavcac3enc: fix custom bitrates
  * ao_alsa: add more workarounds for hardware with broken drivers
    (e.g. ODROID-C2)
  * ao_opensles: remove 32-bit audio formats (not supported by
    Android)
  * cocoa: fix actual display refresh rate retrieval
  * cocoa: use displaylink without manually tracking the display
    id (#2392)
  * command: improve playlist* properties change notifications
    (#3267)
  * command: slightly nicer OSD list formatting
  * compatibility with recent FFmpeg APIs
  * d3d: fix hardware decoding of most MPEG2 things
  * d3dva: move Intel_H264_NoFGT_ClearVideo to lower priority
    (#3059)
  * demux_mkv: better resync behavior for broken google-created
    webms
  * demux_mkv: fix seeking with files that miss the first index
    entry
  * demux_playlist: recognize m3u8 as playlist extension (#3154)
  * input: fix parsing multiple input command prefixes
  * lcms: don't warn/error on 3dlut cache misses
  * lcms: improve black point handling (especially BT.1886)
  * macOS: handle multiple dropped files on the window (#3076)
  * player: always show the first frame in DS mode
  * player: assume video forwards timestamps jumps only with some
    formats (#3027)
  * player: do not update OSD all the time when paused
  * player: eagerly redraw OSD when seeking with coverart
  * player: fix use-after-free with --screenshot-directory (#3049)
  * player: force VO reconfig when unselecting video track
  * player: really start audio only once video is ready
  * sd_lavc: work around bug in older FFmpeg releases (#3109)
  * stream_cdda: enable cache by default
  * sub: fix --sub-gauss
  * vd_lavc: better hwdec wrapper decoder selection
  * vo_opengl: EGL: fix hwdec probing
  * vo_opengl: angle: avoid fullscreen FBO copy for flipping
  * vo_opengl: angle: enable DirectComposition (lowers vsync
    jitter)
  * vo_opengl: angle: prevent DXGI hooking Alt+Enter
  * vo_opengl: avoid outputting ultra-wide-gamut by default
  * vo_opengl: correctly disable interpolation if tscale can't be
    used
  * vo_opengl: fix bicubic_fast in ES mode
  * vo_opengl: fix d3d11 hardware decoding probing on Windows 7
  * vo_opengl: improve scale=oversample performance
  * vo_opengl: make the screen blue on shader errors
  * vo_opengl: partially fix 0bgr format support
  * vo_opengl: possibly update icc profile after changing options
  * vo_opengl: request core profile on X11/EGL too
  * vo_opengl: require at least ES 3.0 for float textures
  * vo_opengl: vdpau: fix certain cases of preemption recovery
    failures
  * vo_rpi: attempt to survive display mode changes
  * vo_rpi: fix destroying overlays (#3100)
  * vo_rpi: wait for vsync with a timeout
  * vo_sdl: fix pixel formats.
  * vo_xv: Handle incorrect size returned by Xv(Shm)CreateImage
    (#320)
  * wayland: correctly report display refresh rate
  * wayland: use the advertised size in fullscreen (#3021, #2657)
  * x11: tell GNOME to use dark window decorations
  * ytdl_hook: fix brightcove urls
  * ytdl_hook: just check if protocol is rtmp (#3090)
  * ytdl_hook: support multi-arc subtitles
- Re-added /etc/mpv/encoding-profiles.conf
* Tue Apr 12 2016 mpluskal@suse.com
- Update dependencies of desktop and icon handling scriplets
* Mon Apr 11 2016 aloisio@gmx.com
- Update to version 0.17.0
  * See https://github.com/mpv-player/mpv/releases/tag/v0.17.0
    for full changelog
* Mon Feb 29 2016 idonmez@suse.com
- Update to v0.16.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.16.0
    for the complete changelog.
- Drop mpv-0.15.0_fix_NULL_ptr.patch, fixed upstream.
- Don't install mpv.png as upstream now ships a mpv.svg
* Mon Feb 15 2016 virtuousfox@gmail.com
- Add a mpv_gpl3 condition to build mpv as GPL-3.0+ on Packman.
* Fri Jan 22 2016 idonmez@suse.com
- Drop the --enable-gpl3 options and revert the license to GPL-2.0+
* Wed Jan 20 2016 aloisio@gmx.com
- Backported commit 5053f4c to fix hang problem with smplayer
  (bug ref. #2729) mpv-0.15.0_fix_NULL_ptr.patch
* Mon Jan 18 2016 idonmez@suse.com
- Update to v0.15.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.15.0
    for the complete changelog.
- Install mpv.conf & input.conf
* Sun Jan 10 2016 idonmez@suse.com
- Set license to GPL-3.0+ so we can enable more OpenGL functionality.
- Add pkgconfig(gl) build dependency.
* Thu Dec 24 2015 tchvatal@suse.com
- Provide and obsolete mplayer2 as per packman discussion
* Mon Dec 14 2015 idonmez@suse.com
- Update to v0.14.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.14.0
    for the complete changelog.
* Fri Dec 11 2015 tchvatal@suse.com
- Remove mpg123 as dependency, thus losing need of being on packman.
  We use the mad implementation anyway if we had FPU and everything
  we support has to have it anyway.
* Fri Dec 11 2015 tchvatal@suse.com
- Sort out the ffmpeg deps to reduce conditionals
* Thu Dec  3 2015 dmueller@suse.com
- only depend on luajit on compatible architectures (doesn't
  exist on e.g. aarch64)
* Tue Nov 10 2015 idonmez@suse.com
- Update to v0.13.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.13.0
    for the complete changelog.
* Thu Oct 29 2015 idonmez@suse.com
- Update to v0.12.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.12.0
    for the complete changelog.
* Fri Oct 23 2015 idonmez@suse.com
- Add a 265x256 resolution app icon
* Wed Sep 23 2015 idonmez@suse.com
- Update to v0.11.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.11.0
    for the complete changelog.
* Fri Sep  4 2015 tchvatal@suse.com
- Bump version of WAF to match upstream
* Fri Sep  4 2015 idonmez@suse.com
- Update to v0.10.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.10.0
    for the complete changelog.
* Wed May 27 2015 tchvatal@suse.com
- Try to fix build for both Factory and packman
  * We neeed to sync this up
* Wed May 27 2015 tchvatal@suse.com
- Version bump to 0.9.2:
  * Various opengl fixes
  * Fulscreen behaviour fixes for some WMs
  * Various other small fixes
* Tue May 19 2015 olaf@aepfle.de
- Sync buildrequires with packman spec-file
* Fri May 15 2015 tchvatal@suse.com
- Sync with packman spec-file
* Wed May  6 2015 mpluskal@suse.com
- Update to 0.9.1
  * mpv's IRC channel moved from #mpv-player to #mpv on chat.freenode.net.
  * Documentation updates.
  * The default value for the --ytdl-format option is now best, in order to work around youtube-dl's 2015.04.26 release enabling DASH by default, as FFmpeg / Libav do not yet properly support DASH.
  * When seeking, the current timestamp will show the predicted seek timestamp instead, until the final timestamp is resolved. Improves UI responsiveness on slow streams and/or large seeks.
- Changes for 0.9.0
  * Note: mpv is not compatible with Lua 5.3. Lua 5.1 or 5.2 is required.
  * The minimum required libass version is now 0.12.1 or newer.
  * The minimum required FFmpeg version is now 2.4.0 (equiv. Libav 11) or newer.
  * The internal libmpg123 support was removed. This was already not used by default in the previous release.
  * The LIRC support was removed. Configure LIRC remotes as input devices instead.
  * The Linux Joystick support was removed.
  * vf_screenshot was removed, as they are now handled at a VO level and is compatible with all VOs.
  * --ass-use-margins has been renamed to --sub-use-margins and applies only to plain-text (non-ASS) subtitles (enabled by default). The new --ass-force-margins option applies only to ASS subtitles (disabled by default). To get the old behaviour back, enable both at the same time.
  * The --sub-scale-with-window option now only applies to plain text (non-ASS) subtitles (enabled by default). The new --ass-scale-with-window option does the same but only with ASS subtitles (disabled by default).
  * The range for the param1 for the gaussian vo_opengl scaler has been redefined. Instead of being an arbitrary 1-100 range, have a default value of 1.0, and anything higher is blurrier.
  * The seek, playlist_next, playlist_prev, loadfile and loadlist parameters no longer accept numerical parameters where symbolic parameter names exist.
  * vo_opengl changes:
  * The smoothmotion suboption has been renamed to interpolation. The old name is still supported for now.
  * The bilinear_slow scaler has been renamed to triangle.
  * scale-down has been renamed to dscale and now has its own set of config options (e.g. dscale-radius).
  * Scaler radius no longer defaults to 3 but to a preferred value that may be different for each filter.
  * The scale-radius option may now go down as low as 0.5, which is the value used by the nearest filter.
  * spline36 is the new cscale default for opengl-hq. This might break setups that use fbo-format=rgb8. To work around it, leave fbo-format as its default, or set to something higher than 8, or set cscale=bilinear, the previous default.
  * vf_format no longer converts video to YUYV if there is no parameter. Video is now passed unchanged unless a format is specifically requested.
  * The --colormatrix, --colormatrix-input-range, --colormatrix-output-range and --colormatrix-primaries options have been converted into vf_format suboptions. See commit 27715b7 and the manual for details.
  * vf_mirror's implementation was replaced with calling into libavfilter's vf_hflip filter, thus depending on libavfilter to function.
  * The device subption to ao_wasapi has been deprecated in favor of --audio-device.
  * --video-rotate now allows 360 as an argument instead of stopping at 359.
  * Several improvements to af_scaletempo.
  * Options that have multiple options and also include a "yes" option now default to that if specified with no arguments.
  * The default value of --cache-default is now 150000 (153.6 MB, ~146 MiB).
  * JPEG screenshots now use the same subsampling as the source video. The images are still RGB regardless of source format though.
* Thu Apr 23 2015 mpluskal@suse.com
- Correct category for library
- Add post/postun scriplet to update icons cache
* Wed Apr 22 2015 mpluskal@suse.com
- Update dependencies (explicitly depend on libav for now)
* Sat Mar 21 2015 mpluskal@suse.com
- Use url for source
- Minor spec file cleanups
* Fri Mar 20 2015 mermoldy@gmail.com
- Version bump to 0.8.3:
  Changes
  * Documentation fixes and updates.
  * (Client API) Clarify mpv_opengl_cb_render's viewport parameter behavior.
  Bug fixes
  * (X11) Fix crash on vo_xv:no-colorkey with the Overlay adapter. (bug #1629)
  * Make the video equalizer work correctly on some VAAPI drivers. (bug #1647)
  * Prevent OSD from disappearing when clicking on mozplugger. (bug #1672)
  * The new DVB-S2 support code, using S2API, now builds on FreeBSD.
  * Fix decoding of seekable matroska from unseekable network stream. (bug #1656)
  * (OSX) Fix crashing when closing a VO's window (usually at exit). (bug #1657)
  * (OSX) Unhide the mouse cursor when over the Dock or Launchpad. (bug #513)
  * (OSX) Fix mouse cursor autohiding when the player is fullscreen.
  * vf_vavpp (VAAPI postprocessing) now deinterlaces video correctly.
  * smb:// streams now use the stream cache (used to be inefficient).
  * (Windows) Do not hide the mouse cursor when it is hovering the window menu.
  * Fix 8-channel output on ao_jack. (bug #1688)
  * Fix --mf-fps parameter on JPEG files. (bug #1689)
  * Fix anamorphic scaling being ignored if it was very minor.
* Fri Jan 30 2015 scarabeus@opensuse.org
- Add BSD-3-Clause license as it is what waf is under
* Thu Jan 29 2015 aloisio@gmx.com
- Version bump to 0.7.3:
  Changes
  * Several documentation updates and typo fixes.
  * Don't show "0%%" position when the stream is infinite / has
    unknown length.
  * Fixes the config file loading order so that lower priority
    `mpv.conf` files don't override higher priority `config` files.
  * The subtitle decoder now gets reset when cycling subtitles.
    This makes the currently shown subtitle event disappear even if
    cycling back to the current subtitle track.
  * `--shuffle` and `--merge-files` now affects the contents of
    playlist files, instead of just the list of files given as
    arguments to mpv.
  * (Linux) `ao_alsa` now deals better with audio device
    disconnection.
  Bug fixes
  * Fixes for handling mono audio on various AOs.
  * (Linux) Fixes resuming from suspend on ao_alsa.
  * Fixes for playlist file parsing.
  * Fix rendering resolution of certain DVB subtitles (bug #1425).
  * Fix EDL or --merge-files breaking timestamps with .avi files.
  * Workaround for libavcodec bug with the VP9 codec parser
    (bug #1448), fixes possible crash.
  * Improve robustness of the matroska parser with broken files
    (bugs #1457, #1461).
  * Improve 10bit video compatibility with older GPUs (specially Intel)
    (bug #1383).
  * Fixes flashing the VO window when playing a list of files that
    includes non-media files (bug #1459).
  * Workaround for window embedding in OpenBox (bug #1235)
  * Fixes for several crashes and lockups (bugs #838, #1389, #1408,
    [#1463], #1473, #1474).
  * Fixes for the zsh completion script (bugs #997)
  New features
  * mpv now prints the contents of its config.h when running in
    verbose mode, to aid with debugging.
  * The `include=` option now accepts `~` to refer to the HOME dir
    (bug #1406).
  * `af_volume` now prints ReplayGain values in verbose mode.
  * m3u playlists that don't have the `#EXTM3U` header are now
    accepted if they "look like" ASCII or UTF-8 text and have the
    .m3u extension.
  * Chapter marks in the seek bar now update when switching files.
  * Supports embedded cover art in MKV files (bug #1374).
  * (Linux) vo_wayland now supports key modifiers (Meta, Alt,
    Control, Shift)
* Thu Dec 25 2014 scarabeus@opensuse.org
- Version bump to 0.7.2:
  * update waf to 0.8.5
  * Give precedence to the DVD menu navigation keyboard bindings so that user
    defined LEFT/RIGHT/... bindings don't break DVD menu navigation.
  * Try to fallback to the "default" device if the selected device is busy in
    the alsa AO.
  * Restore ab-loop settings with playback resume.
  * Don't signal an error if --stream-dump is used.
  * Fix removing key bindings from Lua scripts.
  * Reject channel descriptions with too many channels in the coreaudio AO.
  * Don't async redraw when waiting for VO redraw on OS X (this fixes the very
    annoying glitch where the black bars disappear for a single frame when
    going fullscreen).
  * Fix mono playback with the also AO.
  * Don't crash if framebuffers are not available in the opengl VO.
* Sat Dec 20 2014 seife+obs@b1-systems.com
- fix the UNKNOWN replacement :-)
* Tue Dec 16 2014 scarabeus@opensuse.org
- Replace the UNKNOWN in --version with date from changelog
* Sun Dec 14 2014 scarabeus@opensuse.org
- Quvi was dropped so remove it from the deps
* Fri Dec  5 2014 scarabeus@opensuse.org
- Version bump to 0.7.1:
  * Don't show the volume neutral marker on the OSD if softvol is disabled.
  * Don't select a subtitle track when executing the sub_add input command in "auto" mode.
  * Fix busy loop when seeking while paused (this fixes a problem with pulseaudio that caused mpv and the pulseaudio daemon to use 100%% CPU).
  * Fix Lua function utils.subprocess() in Windows versions older than Vista.
  * Avoid creating a window bigger than the screen on Windows.
  * Don't ignore the last line in m3u playlists.
  * Don't crash if a codec could not be opened.
  * Dynamically allocate audio channel map entries (this should fix a crash in the alsa and coreaudio AOs with audio devices that support more than 20 channel maps).
  * Ignore the "srgb" option in the opengl VO if hardware decoding is enabled.
  * Linearize non-RGB sRGB files correctly (eg. JPEG).
  * Fix opening reference URLs (.file/id=) on OS X.
  * Buffer partial log messages in the client API (the client API will now only pass full log messages to clients).
  * Remove ncurses/terminfo/termcap support (it was disabled by default and replaced by new code since v0.6.0).
  * Enable cdda:// support by default again (it was disabled since v0.6.0).
  * Cascade-load input.conf (if there are several input.confs in the set of valid config paths, load them all).
  * Draw the OSD twice in 3D mode (this fixes subtitles display in 3D mode).
  * Make wasapi the default AO on Windows again since many of its problems have been solved.
  * Use "site-functions" subdir to install the zsh completion script instead of the Debian-specific "vendor-completions" (also provide the --zshdir waf configure option for changing this value).
  * Improve synchronization between the Cocoa GUI and the player (this fixes some long standing deadlock issues on Mac OS X).
  * Remove --fs-missioncontrol option (only relevant to Mac OS X).
  * Enable pitch correction by default when playing at higher speeds (this can be controlled with the --audio-pitch-correction option).
  * Open stream and demuxer asynchronously (this should avoid having the player get blocked on network streams).
  * Add cache-buffering-state property for querying the cache fill status until the player unpauses.
  * Add support for listing and selecting the audio device (note that it is not implemented for all AOs, see the --audio-device option for more information).
  * Add support for a JSON-based IPC mechanism (note that this is not currently supported on Windows, see the JSON IPC section in the manpage for more information).
  * Add Lua utility function for starting processes (see utils.subprocess() in the manpage).
  * Add Lua utility function for parsing JSON (see utils.parse_json() in the manpage).
  * Add field-dominance property (see --field-dominance option).
  * Add video-rotate property (see --video-rotate option).
  * Add playback-abort property for querying whether playback is stopped or is to be stopped.
  * Add cursor-autohide property (see --cursor-autohide option).
  * Add vo-configured property for querying whether a window is created.
  * Add support for dxva2 hardware acceleration on Windows.
  * Drop libquvi support (this has been replaced by a built-in Lua script that invokes the youtube-dl tool, which needs to be installed, see the --ytdl option).
  * Add support for loading chapters from an external file (see the --chapters-file option).
  * Add window-minimized property for querying whether the window is minimized (works for X11 only).
  * Make it possible to configure the OSC seekbar style (see the "seekbarstyle" OSC option).
  * Add support for libmpv on Mac OS X (it used to be broken, now it's fully functional and also provides support for embedding the mpv window inside a Cocoa/Qt application).
  * Try to use the audio channel map reported by ALSA in the alsa AO.
  * Add option to disable text OSD rendering completely (useful for working around certain fontconfig issues, see the --use-text-osd option).
* Mon Nov 24 2014 scarabeus@opensuse.org
- Add --enable-libmpv-shared to build shared library.
* Mon Nov 24 2014 scarabeus@opensuse.org
- Revert back to support wayland.
* Fri Nov 21 2014 scarabeus@opensuse.org
- Blacklist the wayland as it for some reason now have trouble properly
  linking resulting in unresolvable package
* Mon Oct 27 2014 scarabeus@opensuse.org
- Version bump to 0.6.2:
  * The --ass-style-override option now requires a newer version of libass.
  * Correctly signal EOF when using --frames.
  * Strictly endorce the limit imposed by --frames (i.e. avoid producing an extra frame at the end).
  * Fix \x-style escaping when parsing commands.
  * Correctly handle ^h key on the terminal (this should fix the when inserted from Backspace key on new versions of xterm).
  * Don't put the player to sleep after audio reinit.
  * Properly exit if both audio and video fail to initialize.
* Thu Oct 16 2014 scarabeus@opensuse.org
- Version bump to 0.6.1:
  * Don't show message on "osd" command by default (this essentially reverts a change introduced in the last release).
  * Add an alternative input configuration that reverts the key binding changes introduced by previous releases (see etc/restore-old-bindings.conf in the sources).
  * Automatically install example input configuration files.
  * Fix stream languages with Bluray
  * Don't try to create surfaces of size 0 in the VDPAU vo.
  * Don't print audio/video init failure message twice.
  * Fix playback on the root window on X11 (i.e. when using --wid=0).
  * Fix the autodetection of the input format in the vf_stereo3d filter when mpv is built against libav (this makes --video-stereo-mode work with libav as well).
  * Fix compilation with PulseAudio 1.0.
  * Fix compilation with clang.
  * Try harder to decode cover art picture only once.
  * Fix cursor autohide (--cursor-autohide) with audio-only files on file change (e.g. when skipping to the next playlist file).
* Wed Oct  1 2014 aloisio@gmx.com
- Version bump to 0.6.0
  * Numerous changes and new features, see official changelog
* Thu Sep 11 2014 scarabeus@opensuse.org
- Version bump to 0.5.3:
  * Do not honor XDG_CONFIG_DIRS to always read global configs
  * Fix speed behaviour changes
  * Seeking fixes
  * Handle EOF better
* Fri Aug 29 2014 scarabeus@opensuse.org
- Version bump to 0.5.1:
  * Various changes with major release
  * Also look in XDG folders for config
  * Default config renamed to mpv.conf
* Mon Aug  4 2014 scarabeus@opensuse.org
- Version bump to 0.4.2:
  * Fix --cache-file operation when file size is unknown (e.g. when playing from a pipe).
  * Don't sleep if playback is stopped when reconnecting for remote stream.
  * Suspend read on vts change even if the requested title is not found when using dvdnav (dvd://) (this fixes a bug where the DVD menu was not shown properly after a DVD track ended).
  * Avoid draining if the audio output is paused (this fixes a bug where mpv would hang when switching tracks when paused).
  * Drop buffered audio when switching tracks or filters (this fixes a possible regression when using gapless audio).
  * Reverse video rotation direction.
  * Fix initialization of the input when playing from a pipe.
  * Fix description of the --mf option in the manpage (the --mf syntax changed a while ago, but was not documented).
  * Actually append entries to the end of the playlist instead of after the current entry with the "loadlist append" command.
* Sun Jul 13 2014 scarabeus@opensuse.org
- Version bump to 0.4.1:
  * Various small bugfixes
* Tue Jul  1 2014 scarabeus@opensuse.org
- Version bump to 0.4.0:
  * Manpages generating now uses only rst2...
  * Enforce enabling cdda
  * Update requirement for new waf tarball
  + Use dvdnav for dvd:// parsing
  + Various cli arguments changed name see --help for changes
  + Removed radio support
  + For more read https://github.com/mpv-player/mpv/releases/tag/v0.4.0
* Mon Jun 23 2014 scarabeus@opensuse.org
- Version bump to 0.3.11:
  * Small fixes
  * Fix to build with latest git ffmpeg
* Mon May 26 2014 scarabeus@opensuse.org
- Version bump to 0.3.10
  * Various small fixes.
* Wed Apr 30 2014 scarabeus@opensuse.org
- Version bump to 0.3.9:
  * Various small fixes.
* Sun Apr 20 2014 scarabeus@opensuse.org
- Version bump to 0.3.8:
  * Bugfixes around vo=vdpau mostly
* Mon Mar 31 2014 scarabeus@opensuse.org
- Version bump to 0.3.7:
  * Small bugfixes especially around old ffmpeg/libav versions.
* Wed Mar 12 2014 scarabeus@opensuse.org
- Version bumjp to 0.3.6:
  * Various minor bug fixes.
* Sun Feb 16 2014 scarabeus@opensuse.org
- Version bump to 0.3.5:
  * use the c99 to avoid few issues
  * fixes in vo_opengl output
* Tue Feb  4 2014 scarabeus@opensuse.org
- Version bump to 0.3.4:
  * bugfixes all around
  * disabled quvi 0.9 subtitles as they were too broken
* Thu Jan 16 2014 scarabeus@opensuse.org
- Version bump to 0.3.3:
  * Fixes matroska containers
  * Wayland fixes
* Wed Jan  8 2014 scarabeus@opensuse.org
- Version bump to 0.3.2:
  * Fix regression with autoenabling subtitles with quvi
  * Various unspecified bugfixes
* Mon Jan  6 2014 scarabeus@opensuse.org
- Version bump to 0.3.1, fixing few issues.
* Thu Jan  2 2014 scarabeus@opensuse.org
- Drop support for < 12.3 as even 12.2 will be out of scope in 13
  days.
* Mon Dec 30 2013 scarabeus@opensuse.org
- Enable libv4l.
* Mon Dec 30 2013 scarabeus@opensuse.org
- Version bump to 0.3.0:
  * Feature update in various areas, notably support for dvdnav
  * Build system was rewritten under waf
  * Multiple subtitles can be now displayed at once
  * vdpau/vaapi acceleration can be used with opengl output
- Run .desktop file updaters
* Sun Dec  8 2013 scarabeus@opensuse.org
- Version bump to 0.2.4:
  * Audio fixes
  * Small bugfixes
* Sat Nov 23 2013 scarabeus@opensuse.org
- Reduce pkgconfig deps where it seems proper.
* Sat Nov 23 2013 scarabeus@opensuse.org
- Fix docu generating and add luajit dependency.
- Try to convert the deps to pkgconfig syntax.
* Sat Nov  9 2013 scarabeus@opensuse.org
- Verison bump to 0.2.3:
  * Handle more signals
  * Fix audio detection with some formats
  * More tiny fixes
* Wed Nov  6 2013 scarabeus@opensuse.org
- Version bump to 0.2.2:
  * Tiny bugfixes
- Depend on rst2tex when available, still broken configure check
  to be fixed next time.
* Mon Oct 21 2013 scarabeus@opensuse.org
- Version bump to 0.2.1:
  * Various small fixes
- Fix build with samba again, fixed in git properly for next
  release.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Fix directory ownership on icondirs.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Version bump to 0.2.0:
  * new icon
  * Add an On Screen Controller (OSC)
  * Subtitles: make automatic charset detection the default
  * More intuitive chapter seeking behavior
  * support for VA-API hardware decoding and display
  * Preliminary Lua scripting support
  * Switch to GPL version 2 or later for mpv as a whole
* Tue Sep 24 2013 scarabeus@opensuse.org
- Install configuration examples for users to inspire themselves.
* Mon Sep 23 2013 scarabeus@opensuse.org
- Version bump to 0.1.7:
  * manpage fixes
  * mkv subtitle fixes
  * various bugfixes
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make mpv build on 12.2 too, what a release.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Disable jack on 11.4 so the package actually builds.
* Mon Sep 16 2013 scarabeus@opensuse.org
- And make 11.4 happy too wrt dep resolution.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make this work with older releases too (versioned ifs for deps).
* Sun Sep 15 2013 scarabeus@opensuse.org
- Update license and ship readme.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix description.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix dep on python3-docutils as they are borked now, use py2 for
  time being, told sachpe to figure it out.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Sort out remaining dependencies so we can build.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Initial spec file for mpv media player.
  * Based from mplayer2 spec.
